[PATCH 04/17] global: Move remaining CONFIG_SYS_NS16550_* to CFG_SYS_NS16550_*

Tom Rini trini at konsulko.com
Wed Nov 16 19:10:28 CET 2022


The rest of the unmigrated CONFIG symbols in the CONFIG_SYS_NS16550
namespace do not easily transition to Kconfig. In many cases they likely
should come from the device tree instead. Move these out of CONFIG
namespace and in to CFG namespace.

Signed-off-by: Tom Rini <trini at konsulko.com>
---
 arch/arm/cpu/armv7/ls102xa/fdt.c              |  2 +-
 arch/arm/cpu/armv8/fsl-layerscape/fdt.c       |  2 +-
 arch/arm/include/asm/arch-bcmcygnus/configs.h |  6 +-
 arch/arm/include/asm/arch-bcmnsp/configs.h    |  4 +-
 .../asm/arch-fsl-layerscape/immap_lsch2.h     |  8 +--
 .../asm/arch-fsl-layerscape/immap_lsch3.h     |  4 +-
 arch/arm/include/asm/arch-lpc32xx/config.h    |  4 +-
 arch/arm/include/asm/arch-ls102xa/config.h    |  4 +-
 arch/arm/mach-davinci/da850_lowlevel.c        |  6 +-
 arch/arm/mach-davinci/spl.c                   |  4 +-
 arch/arm/mach-keystone/init.c                 |  4 +-
 arch/arm/mach-lpc32xx/devices.c               |  8 +--
 arch/arm/mach-omap2/am33xx/board.c            | 32 +++++-----
 arch/arm/mach-tegra/board.c                   |  4 +-
 arch/powerpc/cpu/mpc85xx/fdt.c                | 12 ++--
 arch/powerpc/include/asm/config.h             |  2 +-
 board/Synology/ds109/ds109.c                  | 10 +--
 board/eets/pdu001/mux.c                       | 12 ++--
 board/emulation/qemu-ppce500/qemu-ppce500.c   |  2 +-
 board/freescale/p1010rdb/p1010rdb.c           |  2 +-
 board/freescale/p1010rdb/spl.c                |  2 +-
 board/freescale/p1010rdb/spl_minimal.c        |  6 +-
 board/freescale/p1_p2_rdb_pc/spl.c            |  2 +-
 board/freescale/p1_p2_rdb_pc/spl_minimal.c    |  6 +-
 board/freescale/t102xrdb/spl.c                |  2 +-
 board/freescale/t104xrdb/spl.c                |  2 +-
 board/freescale/t208xqds/spl.c                |  2 +-
 board/freescale/t208xrdb/spl.c                |  2 +-
 board/freescale/t4rdb/spl.c                   |  2 +-
 board/nokia/rx51/rx51.c                       |  4 +-
 drivers/serial/Kconfig                        |  2 +-
 drivers/serial/ns16550.c                      |  8 +--
 drivers/serial/serial_mtk.c                   | 40 ++++++------
 drivers/serial/serial_ns16550.c               | 64 +++++++++----------
 drivers/serial/serial_omap.c                  |  6 +-
 include/configs/MPC837XERDB.h                 |  6 +-
 include/configs/MPC8548CDS.h                  |  6 +-
 include/configs/P1010RDB.h                    |  6 +-
 include/configs/P2041RDB.h                    | 10 +--
 include/configs/SBx81LIFKW.h                  |  4 +-
 include/configs/SBx81LIFXCAT.h                |  4 +-
 include/configs/T102xRDB.h                    | 10 +--
 include/configs/T104xRDB.h                    | 10 +--
 include/configs/T208xQDS.h                    | 10 +--
 include/configs/T208xRDB.h                    | 10 +--
 include/configs/T4240RDB.h                    | 10 +--
 include/configs/am335x_evm.h                  | 12 ++--
 include/configs/am335x_guardian.h             | 12 ++--
 include/configs/am335x_igep003x.h             |  2 +-
 include/configs/am335x_shc.h                  | 12 ++--
 include/configs/am335x_sl50.h                 | 12 ++--
 include/configs/am43xx_evm.h                  |  4 +-
 include/configs/am57xx_evm.h                  |  6 +-
 include/configs/ap143.h                       |  2 +-
 include/configs/ap152.h                       |  2 +-
 include/configs/apalis-tk1.h                  |  2 +-
 include/configs/apalis_t30.h                  |  2 +-
 include/configs/ax25-ae350.h                  |  2 +-
 include/configs/axs10x.h                      |  2 +-
 include/configs/baltos.h                      | 12 ++--
 include/configs/bcm7260.h                     |  2 +-
 include/configs/bcm7445.h                     |  2 +-
 include/configs/bcm_ns3.h                     |  2 +-
 include/configs/bcmstb.h                      |  2 +-
 include/configs/beaver.h                      |  2 +-
 include/configs/bur_am335x_common.h           |  4 +-
 include/configs/cardhu.h                      |  2 +-
 include/configs/cei-tk1-som.h                 |  2 +-
 include/configs/chiliboard.h                  | 12 ++--
 include/configs/ci20.h                        |  2 +-
 include/configs/cm_t43.h                      |  4 +-
 include/configs/colibri_t20.h                 |  2 +-
 include/configs/colibri_t30.h                 |  2 +-
 include/configs/da850evm.h                    |  2 +-
 include/configs/dalmore.h                     |  2 +-
 include/configs/dra7xx_evm.h                  |  6 +-
 .../configs/gardena-smart-gateway-mt7688.h    |  4 +-
 include/configs/harmony.h                     |  4 +-
 include/configs/hsdk-4xd.h                    |  2 +-
 include/configs/hsdk.h                        |  2 +-
 include/configs/jetson-tk1.h                  |  2 +-
 include/configs/km/pg-wcom-ls102xa.h          |  2 +-
 include/configs/kmcent2.h                     |  4 +-
 include/configs/kontron_sl28.h                |  2 +-
 include/configs/legoev3.h                     |  2 +-
 include/configs/linkit-smart-7688.h           |  4 +-
 include/configs/ls1012a_common.h              |  2 +-
 include/configs/ls1021aiot.h                  |  2 +-
 include/configs/ls1021aqds.h                  |  2 +-
 include/configs/ls1021atsn.h                  |  2 +-
 include/configs/ls1021atwr.h                  |  2 +-
 include/configs/ls1028a_common.h              |  2 +-
 include/configs/ls1043a_common.h              |  2 +-
 include/configs/ls1046a_common.h              |  2 +-
 include/configs/ls1088a_common.h              |  2 +-
 include/configs/ls2080a_common.h              |  2 +-
 include/configs/medcom-wide.h                 |  2 +-
 include/configs/mt7621.h                      |  4 +-
 include/configs/mt7628.h                      |  4 +-
 include/configs/mt8183.h                      |  4 +-
 include/configs/mt8516.h                      |  4 +-
 include/configs/mv-common.h                   |  4 +-
 include/configs/nokia_rx51.h                  |  4 +-
 include/configs/nyan-big.h                    |  2 +-
 include/configs/omap5_uevm.h                  |  2 +-
 include/configs/omapl138_lcdk.h               |  2 +-
 include/configs/p1_p2_rdb_pc.h                |  6 +-
 include/configs/paz00.h                       |  2 +-
 include/configs/pdu001.h                      | 12 ++--
 include/configs/plutux.h                      |  2 +-
 include/configs/seaboard.h                    |  2 +-
 include/configs/siemens-am33x-common.h        |  6 +-
 include/configs/sniper.h                      |  4 +-
 include/configs/socfpga_soc64_common.h        |  2 +-
 include/configs/sunxi-common.h                | 14 ++--
 include/configs/tb100.h                       |  2 +-
 include/configs/tec-ng.h                      |  2 +-
 include/configs/tec.h                         |  2 +-
 include/configs/tegra-common.h                |  2 +-
 include/configs/ti814x_evm.h                  |  4 +-
 include/configs/ti816x_evm.h                  |  4 +-
 include/configs/ti_am335x_common.h            |  2 +-
 include/configs/ti_armv7_keystone2.h          |  8 +--
 include/configs/ti_omap3_common.h             |  8 +--
 include/configs/ti_omap4_common.h             |  4 +-
 include/configs/ti_omap5_common.h             |  2 +-
 include/configs/tplink_wdr4300.h              |  2 +-
 include/configs/trimslice.h                   |  2 +-
 include/configs/vcoreiii.h                    |  2 +-
 include/configs/venice2.h                     |  2 +-
 include/configs/ventana.h                     |  2 +-
 include/configs/vocore2.h                     |  4 +-
 include/configs/x530.h                        |  4 +-
 include/configs/xtfpga.h                      |  4 +-
 134 files changed, 347 insertions(+), 347 deletions(-)

diff --git a/arch/arm/cpu/armv7/ls102xa/fdt.c b/arch/arm/cpu/armv7/ls102xa/fdt.c
index c01cebbf9859..0e7d5fa06dc6 100644
--- a/arch/arm/cpu/armv7/ls102xa/fdt.c
+++ b/arch/arm/cpu/armv7/ls102xa/fdt.c
@@ -125,7 +125,7 @@ void ft_cpu_setup(void *blob, struct bd_info *bd)
 
 #ifdef CONFIG_SYS_NS16550
 	do_fixup_by_compat_u32(blob, "fsl,16550-FIFO64",
-			       "clock-frequency", CONFIG_SYS_NS16550_CLK, 1);
+			       "clock-frequency", CFG_SYS_NS16550_CLK, 1);
 #endif
 
 	sysclk_path = fdt_get_alias(blob, "sysclk");
diff --git a/arch/arm/cpu/armv8/fsl-layerscape/fdt.c b/arch/arm/cpu/armv8/fsl-layerscape/fdt.c
index ee734577fca7..4f91db49eebf 100644
--- a/arch/arm/cpu/armv8/fsl-layerscape/fdt.c
+++ b/arch/arm/cpu/armv8/fsl-layerscape/fdt.c
@@ -646,7 +646,7 @@ void ft_cpu_setup(void *blob, struct bd_info *bd)
 
 #ifdef CONFIG_SYS_NS16550
 	do_fixup_by_compat_u32(blob, "fsl,ns16550",
-			       "clock-frequency", CONFIG_SYS_NS16550_CLK, 1);
+			       "clock-frequency", CFG_SYS_NS16550_CLK, 1);
 #endif
 
 	do_fixup_by_path_u32(blob, "/sysclk", "clock-frequency",
diff --git a/arch/arm/include/asm/arch-bcmcygnus/configs.h b/arch/arm/include/asm/arch-bcmcygnus/configs.h
index 0c7262352d53..fd8dad394ad8 100644
--- a/arch/arm/include/asm/arch-bcmcygnus/configs.h
+++ b/arch/arm/include/asm/arch-bcmcygnus/configs.h
@@ -11,8 +11,8 @@
 /* uArchitecture specifics */
 
 /* Serial Info */
-#define CONFIG_SYS_NS16550_CLK		100000000
-#define CONFIG_SYS_NS16550_CLK_DIV	54
-#define CONFIG_SYS_NS16550_COM3		0x18023000
+#define CFG_SYS_NS16550_CLK		100000000
+#define CFG_SYS_NS16550_CLK_DIV	54
+#define CFG_SYS_NS16550_COM3		0x18023000
 
 #endif /* __ARCH_CONFIGS_H */
diff --git a/arch/arm/include/asm/arch-bcmnsp/configs.h b/arch/arm/include/asm/arch-bcmnsp/configs.h
index 44699476b08b..0d4baf3c0074 100644
--- a/arch/arm/include/asm/arch-bcmnsp/configs.h
+++ b/arch/arm/include/asm/arch-bcmnsp/configs.h
@@ -11,7 +11,7 @@
 /* uArchitecture specifics */
 
 /* Serial Info */
-#define CONFIG_SYS_NS16550_CLK		0x03b9aca0
-#define CONFIG_SYS_NS16550_COM1		0x18000300
+#define CFG_SYS_NS16550_CLK		0x03b9aca0
+#define CFG_SYS_NS16550_COM1		0x18000300
 
 #endif /* __ARCH_CONFIGS_H */
diff --git a/arch/arm/include/asm/arch-fsl-layerscape/immap_lsch2.h b/arch/arm/include/asm/arch-fsl-layerscape/immap_lsch2.h
index e8bd8d27136c..aef615873343 100644
--- a/arch/arm/include/asm/arch-fsl-layerscape/immap_lsch2.h
+++ b/arch/arm/include/asm/arch-fsl-layerscape/immap_lsch2.h
@@ -26,10 +26,10 @@
 #define CFG_SYS_FSL_QMAN_ADDR		(CONFIG_SYS_IMMR + 0x00880000)
 #define CFG_SYS_FSL_SERDES_ADDR		(CONFIG_SYS_IMMR + 0x00ea0000)
 #define CFG_SYS_FSL_CLK_ADDR			(CONFIG_SYS_IMMR + 0x00ee1000)
-#define CONFIG_SYS_NS16550_COM1			(CONFIG_SYS_IMMR + 0x011c0500)
-#define CONFIG_SYS_NS16550_COM2			(CONFIG_SYS_IMMR + 0x011c0600)
-#define CONFIG_SYS_NS16550_COM3			(CONFIG_SYS_IMMR + 0x011d0500)
-#define CONFIG_SYS_NS16550_COM4			(CONFIG_SYS_IMMR + 0x011d0600)
+#define CFG_SYS_NS16550_COM1			(CONFIG_SYS_IMMR + 0x011c0500)
+#define CFG_SYS_NS16550_COM2			(CONFIG_SYS_IMMR + 0x011c0600)
+#define CFG_SYS_NS16550_COM3			(CONFIG_SYS_IMMR + 0x011d0500)
+#define CFG_SYS_NS16550_COM4			(CONFIG_SYS_IMMR + 0x011d0600)
 #define CONFIG_SYS_XHCI_USB1_ADDR		(CONFIG_SYS_IMMR + 0x01f00000)
 #define CONFIG_SYS_XHCI_USB2_ADDR		(CONFIG_SYS_IMMR + 0x02000000)
 #define CONFIG_SYS_XHCI_USB3_ADDR		(CONFIG_SYS_IMMR + 0x02100000)
diff --git a/arch/arm/include/asm/arch-fsl-layerscape/immap_lsch3.h b/arch/arm/include/asm/arch-fsl-layerscape/immap_lsch3.h
index f1ffb2327d63..bad18d778aa0 100644
--- a/arch/arm/include/asm/arch-fsl-layerscape/immap_lsch3.h
+++ b/arch/arm/include/asm/arch-fsl-layerscape/immap_lsch3.h
@@ -35,8 +35,8 @@
 #ifndef CONFIG_NXP_LSCH3_2
 #define CONFIG_SYS_IFC_ADDR			(CONFIG_SYS_IMMR + 0x01240000)
 #endif
-#define CONFIG_SYS_NS16550_COM1			(CONFIG_SYS_IMMR + 0x011C0500)
-#define CONFIG_SYS_NS16550_COM2			(CONFIG_SYS_IMMR + 0x011C0600)
+#define CFG_SYS_NS16550_COM1			(CONFIG_SYS_IMMR + 0x011C0500)
+#define CFG_SYS_NS16550_COM2			(CONFIG_SYS_IMMR + 0x011C0600)
 #define SYS_FSL_LS2080A_LS2085A_TIMER_ADDR	0x023d0000
 #define CFG_SYS_FSL_TIMER_ADDR		0x023e0000
 #define CFG_SYS_FSL_PMU_CLTBENR		(CFG_SYS_FSL_PMU_ADDR + \
diff --git a/arch/arm/include/asm/arch-lpc32xx/config.h b/arch/arm/include/asm/arch-lpc32xx/config.h
index 5dd90b47f939..6de431f6bbbc 100644
--- a/arch/arm/include/asm/arch-lpc32xx/config.h
+++ b/arch/arm/include/asm/arch-lpc32xx/config.h
@@ -19,8 +19,8 @@
 #endif
 #endif
 
-#if !defined(CONFIG_SYS_NS16550_CLK)
-#define CONFIG_SYS_NS16550_CLK		13000000
+#if !defined(CFG_SYS_NS16550_CLK)
+#define CFG_SYS_NS16550_CLK		13000000
 #endif
 
 #define CONFIG_SYS_BAUDRATE_TABLE	\
diff --git a/arch/arm/include/asm/arch-ls102xa/config.h b/arch/arm/include/asm/arch-ls102xa/config.h
index e85918eb7ec5..033341dbfb63 100644
--- a/arch/arm/include/asm/arch-ls102xa/config.h
+++ b/arch/arm/include/asm/arch-ls102xa/config.h
@@ -30,8 +30,8 @@
 #define CFG_SYS_FSL_GUTS_ADDR		(CONFIG_SYS_IMMR + 0x00ee0000)
 #define CFG_SYS_FSL_LS1_CLK_ADDR		(CONFIG_SYS_IMMR + 0x00ee1000)
 #define CFG_SYS_FSL_RCPM_ADDR		(CONFIG_SYS_IMMR + 0x00ee2000)
-#define CONFIG_SYS_NS16550_COM1			(CONFIG_SYS_IMMR + 0x011c0500)
-#define CONFIG_SYS_NS16550_COM2			(CONFIG_SYS_IMMR + 0x011d0500)
+#define CFG_SYS_NS16550_COM1			(CONFIG_SYS_IMMR + 0x011c0500)
+#define CFG_SYS_NS16550_COM2			(CONFIG_SYS_IMMR + 0x011d0500)
 #define CONFIG_SYS_XHCI_USB1_ADDR		(CONFIG_SYS_IMMR + 0x02100000)
 
 #define CFG_SYS_FSL_SEC_OFFSET		0x00700000
diff --git a/arch/arm/mach-davinci/da850_lowlevel.c b/arch/arm/mach-davinci/da850_lowlevel.c
index 759c93747c75..2319ac6d5631 100644
--- a/arch/arm/mach-davinci/da850_lowlevel.c
+++ b/arch/arm/mach-davinci/da850_lowlevel.c
@@ -290,8 +290,8 @@ int arch_cpu_init(void)
 	board_gpio_init();
 
 #if !CONFIG_IS_ENABLED(DM_SERIAL)
-	ns16550_init((struct ns16550 *)(CONFIG_SYS_NS16550_COM1),
-		     CONFIG_SYS_NS16550_CLK / 16 / CONFIG_BAUDRATE);
+	ns16550_init((struct ns16550 *)(CFG_SYS_NS16550_COM1),
+		     CFG_SYS_NS16550_CLK / 16 / CONFIG_BAUDRATE);
 #endif
 	/*
 	 * Fix Power and Emulation Management Register
@@ -299,7 +299,7 @@ int arch_cpu_init(void)
 	 */
 	writel((DAVINCI_UART_PWREMU_MGMT_FREE | DAVINCI_UART_PWREMU_MGMT_URRST |
 		DAVINCI_UART_PWREMU_MGMT_UTRST),
-#if (CONFIG_SYS_NS16550_COM1 == DAVINCI_UART0_BASE)
+#if (CFG_SYS_NS16550_COM1 == DAVINCI_UART0_BASE)
 	       &davinci_uart0_ctrl_regs->pwremu_mgmt);
 #else
 	       &davinci_uart2_ctrl_regs->pwremu_mgmt);
diff --git a/arch/arm/mach-davinci/spl.c b/arch/arm/mach-davinci/spl.c
index 54aff78894a5..5f5b9ebbf97a 100644
--- a/arch/arm/mach-davinci/spl.c
+++ b/arch/arm/mach-davinci/spl.c
@@ -27,9 +27,9 @@ void puts(const char *str)
 void putc(char c)
 {
 	if (c == '\n')
-		ns16550_putc((struct ns16550 *)(CONFIG_SYS_NS16550_COM1), '\r');
+		ns16550_putc((struct ns16550 *)(CFG_SYS_NS16550_COM1), '\r');
 
-	ns16550_putc((struct ns16550 *)(CONFIG_SYS_NS16550_COM1), c);
+	ns16550_putc((struct ns16550 *)(CFG_SYS_NS16550_COM1), c);
 }
 #endif /* CONFIG_SPL_LIBCOMMON_SUPPORT */
 
diff --git a/arch/arm/mach-keystone/init.c b/arch/arm/mach-keystone/init.c
index 5b95f6050019..1954e69e9f0d 100644
--- a/arch/arm/mach-keystone/init.c
+++ b/arch/arm/mach-keystone/init.c
@@ -185,8 +185,8 @@ int arch_cpu_init(void)
 	 * driver doesn't handle this.
 	 */
 #ifndef CONFIG_DM_SERIAL
-	ns16550_init((struct ns16550 *)(CONFIG_SYS_NS16550_COM2),
-		     CONFIG_SYS_NS16550_CLK / 16 / CONFIG_BAUDRATE);
+	ns16550_init((struct ns16550 *)(CFG_SYS_NS16550_COM2),
+		     CFG_SYS_NS16550_CLK / 16 / CONFIG_BAUDRATE);
 #endif
 
 	return 0;
diff --git a/arch/arm/mach-lpc32xx/devices.c b/arch/arm/mach-lpc32xx/devices.c
index 0a4fef295a36..3fcf8facb411 100644
--- a/arch/arm/mach-lpc32xx/devices.c
+++ b/arch/arm/mach-lpc32xx/devices.c
@@ -44,13 +44,13 @@ void lpc32xx_uart_init(unsigned int uart_id)
 #if !CONFIG_IS_ENABLED(OF_CONTROL)
 static const struct ns16550_plat lpc32xx_uart[] = {
 	{ .base = UART3_BASE, .reg_shift = 2,
-	  .clock = CONFIG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
+	  .clock = CFG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
 	{ .base = UART4_BASE, .reg_shift = 2,
-	  .clock = CONFIG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
+	  .clock = CFG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
 	{ .base = UART5_BASE, .reg_shift = 2,
-	  .clock = CONFIG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
+	  .clock = CFG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
 	{ .base = UART6_BASE, .reg_shift = 2,
-	  .clock = CONFIG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
+	  .clock = CFG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
 };
 
 #if defined(CONFIG_LPC32XX_HSUART)
diff --git a/arch/arm/mach-omap2/am33xx/board.c b/arch/arm/mach-omap2/am33xx/board.c
index f393ff91441f..44d5214a3df1 100644
--- a/arch/arm/mach-omap2/am33xx/board.c
+++ b/arch/arm/mach-omap2/am33xx/board.c
@@ -87,29 +87,29 @@ int dram_init_banksize(void)
 
 #if !CONFIG_IS_ENABLED(OF_CONTROL)
 static const struct ns16550_plat am33xx_serial[] = {
-	{ .base = CONFIG_SYS_NS16550_COM1, .reg_shift = 2,
-	  .clock = CONFIG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
-# ifdef CONFIG_SYS_NS16550_COM2
-	{ .base = CONFIG_SYS_NS16550_COM2, .reg_shift = 2,
-	  .clock = CONFIG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
-#  ifdef CONFIG_SYS_NS16550_COM3
-	{ .base = CONFIG_SYS_NS16550_COM3, .reg_shift = 2,
-	  .clock = CONFIG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
-	{ .base = CONFIG_SYS_NS16550_COM4, .reg_shift = 2,
-	  .clock = CONFIG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
-	{ .base = CONFIG_SYS_NS16550_COM5, .reg_shift = 2,
-	  .clock = CONFIG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
-	{ .base = CONFIG_SYS_NS16550_COM6, .reg_shift = 2,
-	  .clock = CONFIG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
+	{ .base = CFG_SYS_NS16550_COM1, .reg_shift = 2,
+	  .clock = CFG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
+# ifdef CFG_SYS_NS16550_COM2
+	{ .base = CFG_SYS_NS16550_COM2, .reg_shift = 2,
+	  .clock = CFG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
+#  ifdef CFG_SYS_NS16550_COM3
+	{ .base = CFG_SYS_NS16550_COM3, .reg_shift = 2,
+	  .clock = CFG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
+	{ .base = CFG_SYS_NS16550_COM4, .reg_shift = 2,
+	  .clock = CFG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
+	{ .base = CFG_SYS_NS16550_COM5, .reg_shift = 2,
+	  .clock = CFG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
+	{ .base = CFG_SYS_NS16550_COM6, .reg_shift = 2,
+	  .clock = CFG_SYS_NS16550_CLK, .fcr = UART_FCR_DEFVAL, },
 #  endif
 # endif
 };
 
 U_BOOT_DRVINFOS(am33xx_uarts) = {
 	{ "ns16550_serial", &am33xx_serial[0] },
-#  ifdef CONFIG_SYS_NS16550_COM2
+#  ifdef CFG_SYS_NS16550_COM2
 	{ "ns16550_serial", &am33xx_serial[1] },
-#   ifdef CONFIG_SYS_NS16550_COM3
+#   ifdef CFG_SYS_NS16550_COM3
 	{ "ns16550_serial", &am33xx_serial[2] },
 	{ "ns16550_serial", &am33xx_serial[3] },
 	{ "ns16550_serial", &am33xx_serial[4] },
diff --git a/arch/arm/mach-tegra/board.c b/arch/arm/mach-tegra/board.c
index 95d6555a0d25..f8b61a2b3e3b 100644
--- a/arch/arm/mach-tegra/board.c
+++ b/arch/arm/mach-tegra/board.c
@@ -259,9 +259,9 @@ void board_init_uart_f(void)
 
 #if !CONFIG_IS_ENABLED(OF_CONTROL)
 static struct ns16550_plat ns16550_com1_pdata = {
-	.base = CONFIG_SYS_NS16550_COM1,
+	.base = CFG_SYS_NS16550_COM1,
 	.reg_shift = 2,
-	.clock = CONFIG_SYS_NS16550_CLK,
+	.clock = CFG_SYS_NS16550_CLK,
 	.fcr = UART_FCR_DEFVAL,
 };
 
diff --git a/arch/powerpc/include/asm/config.h b/arch/powerpc/include/asm/config.h
index 79fe567b5875..b0ad7d7aa728 100644
--- a/arch/powerpc/include/asm/config.h
+++ b/arch/powerpc/include/asm/config.h
@@ -52,7 +52,7 @@
  * TODO: Convert this to a clock driver exists that can give us the UART
  * clock here.
  */
-#define CONFIG_SYS_NS16550_CLK		get_serial_clock()
+#define CFG_SYS_NS16550_CLK		get_serial_clock()
 #endif
 
 #endif /* _ASM_CONFIG_H_ */
diff --git a/board/Synology/ds109/ds109.c b/board/Synology/ds109/ds109.c
index 9e7f6ac6c792..5c3f46e23f46 100644
--- a/board/Synology/ds109/ds109.c
+++ b/board/Synology/ds109/ds109.c
@@ -101,17 +101,17 @@ int board_init(void)
 #include <ns16550.h>
 #define SOFTWARE_SHUTDOWN   0x31
 #define SOFTWARE_REBOOT     0x43
-#define CONFIG_SYS_NS16550_COM2		KW_UART1_BASE
+#define CFG_SYS_NS16550_COM2		KW_UART1_BASE
 void reset_misc(void)
 {
 	int b_d;
 	printf("Synology reset...");
 	udelay(50000);
 
-	b_d = ns16550_calc_divisor((struct ns16550 *)CONFIG_SYS_NS16550_COM2,
-				   CONFIG_SYS_NS16550_CLK, 9600);
-	ns16550_init((struct ns16550 *)CONFIG_SYS_NS16550_COM2, b_d);
-	ns16550_putc((struct ns16550 *)CONFIG_SYS_NS16550_COM2,
+	b_d = ns16550_calc_divisor((struct ns16550 *)CFG_SYS_NS16550_COM2,
+				   CFG_SYS_NS16550_CLK, 9600);
+	ns16550_init((struct ns16550 *)CFG_SYS_NS16550_COM2, b_d);
+	ns16550_putc((struct ns16550 *)CFG_SYS_NS16550_COM2,
 		     SOFTWARE_REBOOT);
 }
 
diff --git a/board/eets/pdu001/mux.c b/board/eets/pdu001/mux.c
index f0f9e262ebdb..886fef60b0af 100644
--- a/board/eets/pdu001/mux.c
+++ b/board/eets/pdu001/mux.c
@@ -92,22 +92,22 @@ void enable_uart5_pin_mux(void)
 void enable_uart_pin_mux(u32 addr)
 {
 	switch (addr) {
-	case CONFIG_SYS_NS16550_COM1:
+	case CFG_SYS_NS16550_COM1:
 		enable_uart0_pin_mux();
 		break;
-	case CONFIG_SYS_NS16550_COM2:
+	case CFG_SYS_NS16550_COM2:
 		enable_uart1_pin_mux();
 		break;
-	case CONFIG_SYS_NS16550_COM3:
+	case CFG_SYS_NS16550_COM3:
 		enable_uart2_pin_mux();
 		break;
-	case CONFIG_SYS_NS16550_COM4:
+	case CFG_SYS_NS16550_COM4:
 		enable_uart3_pin_mux();
 		break;
-	case CONFIG_SYS_NS16550_COM5:
+	case CFG_SYS_NS16550_COM5:
 		enable_uart4_pin_mux();
 		break;
-	case CONFIG_SYS_NS16550_COM6:
+	case CFG_SYS_NS16550_COM6:
 		enable_uart5_pin_mux();
 		break;
 	}
diff --git a/board/emulation/qemu-ppce500/qemu-ppce500.c b/board/emulation/qemu-ppce500/qemu-ppce500.c
index 99edaa3b4215..a4254250bbf3 100644
--- a/board/emulation/qemu-ppce500/qemu-ppce500.c
+++ b/board/emulation/qemu-ppce500/qemu-ppce500.c
@@ -343,7 +343,7 @@ void *board_fdt_blob_setup(int *err)
 	return get_fdt_virt();
 }
 
-/* See CONFIG_SYS_NS16550_CLK in arch/powerpc/include/asm/config.h */
+/* See CFG_SYS_NS16550_CLK in arch/powerpc/include/asm/config.h */
 int get_serial_clock(void)
 {
 	return get_bus_freq(0);
diff --git a/board/freescale/p1010rdb/p1010rdb.c b/board/freescale/p1010rdb/p1010rdb.c
index c39df462e3bb..ab3b2e3e69b5 100644
--- a/board/freescale/p1010rdb/p1010rdb.c
+++ b/board/freescale/p1010rdb/p1010rdb.c
@@ -587,7 +587,7 @@ void fdt_disable_uart1(void *blob)
 	int nodeoff;
 
 	nodeoff = fdt_node_offset_by_compat_reg(blob, "fsl,ns16550",
-					CONFIG_SYS_NS16550_COM2);
+					CFG_SYS_NS16550_COM2);
 
 	if (nodeoff > 0) {
 		fdt_status_disabled(blob, nodeoff);
diff --git a/board/freescale/p1010rdb/spl.c b/board/freescale/p1010rdb/spl.c
index 0db11f4c5f79..9bf948cb5c96 100644
--- a/board/freescale/p1010rdb/spl.c
+++ b/board/freescale/p1010rdb/spl.c
@@ -45,7 +45,7 @@ void board_init_f(ulong bootflag)
 	plat_ratio >>= 1;
 	gd->bus_clk = get_board_sys_clk() * plat_ratio;
 
-	ns16550_init((struct ns16550 *)CONFIG_SYS_NS16550_COM1,
+	ns16550_init((struct ns16550 *)CFG_SYS_NS16550_COM1,
 		     gd->bus_clk / 16 / CONFIG_BAUDRATE);
 
 #ifdef CONFIG_SPL_MMC_BOOT
diff --git a/board/freescale/p1010rdb/spl_minimal.c b/board/freescale/p1010rdb/spl_minimal.c
index 9cd46c966410..8f0dec4c0ab7 100644
--- a/board/freescale/p1010rdb/spl_minimal.c
+++ b/board/freescale/p1010rdb/spl_minimal.c
@@ -32,7 +32,7 @@ void board_init_f(ulong bootflag)
 	plat_ratio >>= 1;
 	gd->bus_clk = get_board_sys_clk() * plat_ratio;
 
-	ns16550_init((struct ns16550 *)CONFIG_SYS_NS16550_COM1,
+	ns16550_init((struct ns16550 *)CFG_SYS_NS16550_COM1,
 		     gd->bus_clk / 16 / CONFIG_BAUDRATE);
 
 	puts("\nNAND boot... ");
@@ -54,9 +54,9 @@ void board_init_r(gd_t *gd, ulong dest_addr)
 void putc(char c)
 {
 	if (c == '\n')
-		ns16550_putc((struct ns16550 *)CONFIG_SYS_NS16550_COM1, '\r');
+		ns16550_putc((struct ns16550 *)CFG_SYS_NS16550_COM1, '\r');
 
-	ns16550_putc((struct ns16550 *)CONFIG_SYS_NS16550_COM1, c);
+	ns16550_putc((struct ns16550 *)CFG_SYS_NS16550_COM1, c);
 }
 
 void puts(const char *str)
diff --git a/board/freescale/p1_p2_rdb_pc/spl.c b/board/freescale/p1_p2_rdb_pc/spl.c
index e7d4428d7c22..6c3f82849e3a 100644
--- a/board/freescale/p1_p2_rdb_pc/spl.c
+++ b/board/freescale/p1_p2_rdb_pc/spl.c
@@ -57,7 +57,7 @@ void board_init_f(ulong bootflag)
 	bus_clk = get_board_sys_clk() * plat_ratio;
 	gd->bus_clk = bus_clk;
 
-	ns16550_init((struct ns16550 *)CONFIG_SYS_NS16550_COM1,
+	ns16550_init((struct ns16550 *)CFG_SYS_NS16550_COM1,
 		     bus_clk / 16 / CONFIG_BAUDRATE);
 #ifdef CONFIG_SPL_MMC_BOOT
 	puts("\nSD boot...\n");
diff --git a/board/freescale/p1_p2_rdb_pc/spl_minimal.c b/board/freescale/p1_p2_rdb_pc/spl_minimal.c
index 2fd8a2874333..f9e0b5b25ab7 100644
--- a/board/freescale/p1_p2_rdb_pc/spl_minimal.c
+++ b/board/freescale/p1_p2_rdb_pc/spl_minimal.c
@@ -31,7 +31,7 @@ void board_init_f(ulong bootflag)
 	plat_ratio >>= 1;
 	gd->bus_clk = get_board_sys_clk() * plat_ratio;
 
-	ns16550_init((struct ns16550 *)CONFIG_SYS_NS16550_COM1,
+	ns16550_init((struct ns16550 *)CFG_SYS_NS16550_COM1,
 		     gd->bus_clk / 16 / CONFIG_BAUDRATE);
 
 	puts("\nNAND boot... ");
@@ -52,9 +52,9 @@ void board_init_r(gd_t *gd, ulong dest_addr)
 void putc(char c)
 {
 	if (c == '\n')
-		ns16550_putc((struct ns16550 *)CONFIG_SYS_NS16550_COM1, '\r');
+		ns16550_putc((struct ns16550 *)CFG_SYS_NS16550_COM1, '\r');
 
-	ns16550_putc((struct ns16550 *)CONFIG_SYS_NS16550_COM1, c);
+	ns16550_putc((struct ns16550 *)CFG_SYS_NS16550_COM1, c);
 }
 
 void puts(const char *str)
diff --git a/board/freescale/t102xrdb/spl.c b/board/freescale/t102xrdb/spl.c
index 3ba94fecaa24..9faf259af74d 100644
--- a/board/freescale/t102xrdb/spl.c
+++ b/board/freescale/t102xrdb/spl.c
@@ -73,7 +73,7 @@ void board_init_f(ulong bootflag)
 	plat_ratio = (in_be32(&gur->rcwsr[0]) >> 25) & 0x1f;
 	ccb_clk = sys_clk * plat_ratio / 2;
 
-	ns16550_init((struct ns16550 *)CONFIG_SYS_NS16550_COM1,
+	ns16550_init((struct ns16550 *)CFG_SYS_NS16550_COM1,
 		     ccb_clk / 16 / CONFIG_BAUDRATE);
 
 #if defined(CONFIG_SPL_MMC_BOOT)
diff --git a/board/freescale/t104xrdb/spl.c b/board/freescale/t104xrdb/spl.c
index c7fb4272c63b..66a142b3ad03 100644
--- a/board/freescale/t104xrdb/spl.c
+++ b/board/freescale/t104xrdb/spl.c
@@ -72,7 +72,7 @@ void board_init_f(ulong bootflag)
 	plat_ratio = (in_be32(&gur->rcwsr[0]) >> 25) & 0x1f;
 	uart_clk = sys_clk * plat_ratio / 2;
 
-	ns16550_init((struct ns16550 *)CONFIG_SYS_NS16550_COM1,
+	ns16550_init((struct ns16550 *)CFG_SYS_NS16550_COM1,
 		     uart_clk / 16 / CONFIG_BAUDRATE);
 
 	relocate_code(CONFIG_SPL_RELOC_STACK, (gd_t *)CONFIG_SPL_GD_ADDR, 0x0);
diff --git a/board/freescale/t208xqds/spl.c b/board/freescale/t208xqds/spl.c
index 8b68329b9864..8866be54a661 100644
--- a/board/freescale/t208xqds/spl.c
+++ b/board/freescale/t208xqds/spl.c
@@ -82,7 +82,7 @@ void board_init_f(ulong bootflag)
 	plat_ratio = (in_be32(&gur->rcwsr[0]) >> 25) & 0x1f;
 	ccb_clk = sys_clk * plat_ratio / 2;
 
-	ns16550_init((struct ns16550 *)CONFIG_SYS_NS16550_COM1,
+	ns16550_init((struct ns16550 *)CFG_SYS_NS16550_COM1,
 		     ccb_clk / 16 / CONFIG_BAUDRATE);
 
 #if defined(CONFIG_SPL_MMC_BOOT)
diff --git a/board/freescale/t208xrdb/spl.c b/board/freescale/t208xrdb/spl.c
index 3f9b1faa853e..130cb8847c0f 100644
--- a/board/freescale/t208xrdb/spl.c
+++ b/board/freescale/t208xrdb/spl.c
@@ -42,7 +42,7 @@ void board_init_f(ulong bootflag)
 	plat_ratio = (in_be32(&gur->rcwsr[0]) >> 25) & 0x1f;
 	ccb_clk = sys_clk * plat_ratio / 2;
 
-	ns16550_init((struct ns16550 *)CONFIG_SYS_NS16550_COM1,
+	ns16550_init((struct ns16550 *)CFG_SYS_NS16550_COM1,
 		     ccb_clk / 16 / CONFIG_BAUDRATE);
 
 #if defined(CONFIG_SPL_MMC_BOOT)
diff --git a/board/freescale/t4rdb/spl.c b/board/freescale/t4rdb/spl.c
index 72d3b80b19b2..779457d29640 100644
--- a/board/freescale/t4rdb/spl.c
+++ b/board/freescale/t4rdb/spl.c
@@ -51,7 +51,7 @@ void board_init_f(ulong bootflag)
 	plat_ratio = (in_be32(&gur->rcwsr[0]) >> 25) & 0x1f;
 	ccb_clk = sys_clk * plat_ratio / 2;
 
-	ns16550_init((struct ns16550 *)CONFIG_SYS_NS16550_COM1,
+	ns16550_init((struct ns16550 *)CFG_SYS_NS16550_COM1,
 		     ccb_clk / 16 / CONFIG_BAUDRATE);
 
 	puts("\nSD boot...\n");
diff --git a/board/nokia/rx51/rx51.c b/board/nokia/rx51/rx51.c
index c1b4b91b6070..fa95886fa3b6 100644
--- a/board/nokia/rx51/rx51.c
+++ b/board/nokia/rx51/rx51.c
@@ -795,9 +795,9 @@ U_BOOT_DRVINFOS(rx51_kp) = {
 };
 
 static const struct ns16550_plat rx51_serial = {
-	.base = CONFIG_SYS_NS16550_COM3,
+	.base = CFG_SYS_NS16550_COM3,
 	.reg_shift = 2,
-	.clock = CONFIG_SYS_NS16550_CLK,
+	.clock = CFG_SYS_NS16550_CLK,
 	.fcr = UART_FCR_DEFVAL,
 };
 
diff --git a/drivers/serial/Kconfig b/drivers/serial/Kconfig
index 45a34495dfb9..12dbb3d35fd7 100644
--- a/drivers/serial/Kconfig
+++ b/drivers/serial/Kconfig
@@ -730,7 +730,7 @@ config SYS_NS16550
 	  Support NS16550 UART or compatible. This can be enabled in the
 	  device tree with the correct input clock frequency. If the input
 	  clock frequency is not defined in the device tree, the macro
-	  CONFIG_SYS_NS16550_CLK defined in a legacy board header file will
+	  CFG_SYS_NS16550_CLK defined in a legacy board header file will
 	  be used. It can be a constant or a function to get clock, eg,
 	  get_serial_clock().
 
diff --git a/drivers/serial/ns16550.c b/drivers/serial/ns16550.c
index 5a693d2f02ae..772dd6fef8f3 100644
--- a/drivers/serial/ns16550.c
+++ b/drivers/serial/ns16550.c
@@ -92,8 +92,8 @@ static inline int serial_in_shift(void *addr, int shift)
 
 #if CONFIG_IS_ENABLED(DM_SERIAL)
 
-#ifndef CONFIG_SYS_NS16550_CLK
-#define CONFIG_SYS_NS16550_CLK  0
+#ifndef CFG_SYS_NS16550_CLK
+#define CFG_SYS_NS16550_CLK  0
 #endif
 
 /*
@@ -567,9 +567,9 @@ int ns16550_serial_of_to_plat(struct udevice *dev)
 
 	if (!plat->clock)
 		plat->clock = dev_read_u32_default(dev, "clock-frequency",
-						   CONFIG_SYS_NS16550_CLK);
+						   CFG_SYS_NS16550_CLK);
 	if (!plat->clock)
-		plat->clock = CONFIG_SYS_NS16550_CLK;
+		plat->clock = CFG_SYS_NS16550_CLK;
 	if (!plat->clock) {
 		debug("ns16550 clock not defined\n");
 		return -EINVAL;
diff --git a/drivers/serial/serial_mtk.c b/drivers/serial/serial_mtk.c
index 03b9e86bfc20..6fb4cb65c29f 100644
--- a/drivers/serial/serial_mtk.c
+++ b/drivers/serial/serial_mtk.c
@@ -284,8 +284,8 @@ DECLARE_GLOBAL_DATA_PTR;
 
 #define DECLARE_HSUART_PRIV(port) \
 	static struct mtk_serial_priv mtk_hsuart##port = { \
-	.regs = (struct mtk_serial_regs *)CONFIG_SYS_NS16550_COM##port, \
-	.fixed_clk_rate = CONFIG_SYS_NS16550_CLK \
+	.regs = (struct mtk_serial_regs *)CFG_SYS_NS16550_COM##port, \
+	.fixed_clk_rate = CFG_SYS_NS16550_CLK \
 };
 
 #define DECLARE_HSUART_FUNCTIONS(port) \
@@ -356,36 +356,36 @@ DECLARE_GLOBAL_DATA_PTR;
 #error	"Invalid console index value."
 #endif
 
-#if CONFIG_CONS_INDEX == 1 && !defined(CONFIG_SYS_NS16550_COM1)
+#if CONFIG_CONS_INDEX == 1 && !defined(CFG_SYS_NS16550_COM1)
 #error	"Console port 1 defined but not configured."
-#elif CONFIG_CONS_INDEX == 2 && !defined(CONFIG_SYS_NS16550_COM2)
+#elif CONFIG_CONS_INDEX == 2 && !defined(CFG_SYS_NS16550_COM2)
 #error	"Console port 2 defined but not configured."
-#elif CONFIG_CONS_INDEX == 3 && !defined(CONFIG_SYS_NS16550_COM3)
+#elif CONFIG_CONS_INDEX == 3 && !defined(CFG_SYS_NS16550_COM3)
 #error	"Console port 3 defined but not configured."
-#elif CONFIG_CONS_INDEX == 4 && !defined(CONFIG_SYS_NS16550_COM4)
+#elif CONFIG_CONS_INDEX == 4 && !defined(CFG_SYS_NS16550_COM4)
 #error	"Console port 4 defined but not configured."
-#elif CONFIG_CONS_INDEX == 5 && !defined(CONFIG_SYS_NS16550_COM5)
+#elif CONFIG_CONS_INDEX == 5 && !defined(CFG_SYS_NS16550_COM5)
 #error	"Console port 5 defined but not configured."
-#elif CONFIG_CONS_INDEX == 6 && !defined(CONFIG_SYS_NS16550_COM6)
+#elif CONFIG_CONS_INDEX == 6 && !defined(CFG_SYS_NS16550_COM6)
 #error	"Console port 6 defined but not configured."
 #endif
 
-#if defined(CONFIG_SYS_NS16550_COM1)
+#if defined(CFG_SYS_NS16550_COM1)
 DECLARE_HSUART(1, "mtk-hsuart0");
 #endif
-#if defined(CONFIG_SYS_NS16550_COM2)
+#if defined(CFG_SYS_NS16550_COM2)
 DECLARE_HSUART(2, "mtk-hsuart1");
 #endif
-#if defined(CONFIG_SYS_NS16550_COM3)
+#if defined(CFG_SYS_NS16550_COM3)
 DECLARE_HSUART(3, "mtk-hsuart2");
 #endif
-#if defined(CONFIG_SYS_NS16550_COM4)
+#if defined(CFG_SYS_NS16550_COM4)
 DECLARE_HSUART(4, "mtk-hsuart3");
 #endif
-#if defined(CONFIG_SYS_NS16550_COM5)
+#if defined(CFG_SYS_NS16550_COM5)
 DECLARE_HSUART(5, "mtk-hsuart4");
 #endif
-#if defined(CONFIG_SYS_NS16550_COM6)
+#if defined(CFG_SYS_NS16550_COM6)
 DECLARE_HSUART(6, "mtk-hsuart5");
 #endif
 
@@ -410,22 +410,22 @@ __weak struct serial_device *default_serial_console(void)
 
 void mtk_serial_initialize(void)
 {
-#if defined(CONFIG_SYS_NS16550_COM1)
+#if defined(CFG_SYS_NS16550_COM1)
 	serial_register(&mtk_hsuart1_device);
 #endif
-#if defined(CONFIG_SYS_NS16550_COM2)
+#if defined(CFG_SYS_NS16550_COM2)
 	serial_register(&mtk_hsuart2_device);
 #endif
-#if defined(CONFIG_SYS_NS16550_COM3)
+#if defined(CFG_SYS_NS16550_COM3)
 	serial_register(&mtk_hsuart3_device);
 #endif
-#if defined(CONFIG_SYS_NS16550_COM4)
+#if defined(CFG_SYS_NS16550_COM4)
 	serial_register(&mtk_hsuart4_device);
 #endif
-#if defined(CONFIG_SYS_NS16550_COM5)
+#if defined(CFG_SYS_NS16550_COM5)
 	serial_register(&mtk_hsuart5_device);
 #endif
-#if defined(CONFIG_SYS_NS16550_COM6)
+#if defined(CFG_SYS_NS16550_COM6)
 	serial_register(&mtk_hsuart6_device);
 #endif
 }
diff --git a/drivers/serial/serial_ns16550.c b/drivers/serial/serial_ns16550.c
index 76aa1e5afb42..4014f6820400 100644
--- a/drivers/serial/serial_ns16550.c
+++ b/drivers/serial/serial_ns16550.c
@@ -20,17 +20,17 @@ DECLARE_GLOBAL_DATA_PTR;
 #error	"Invalid console index value."
 #endif
 
-#if CONFIG_CONS_INDEX == 1 && !defined(CONFIG_SYS_NS16550_COM1)
+#if CONFIG_CONS_INDEX == 1 && !defined(CFG_SYS_NS16550_COM1)
 #error	"Console port 1 defined but not configured."
-#elif CONFIG_CONS_INDEX == 2 && !defined(CONFIG_SYS_NS16550_COM2)
+#elif CONFIG_CONS_INDEX == 2 && !defined(CFG_SYS_NS16550_COM2)
 #error	"Console port 2 defined but not configured."
-#elif CONFIG_CONS_INDEX == 3 && !defined(CONFIG_SYS_NS16550_COM3)
+#elif CONFIG_CONS_INDEX == 3 && !defined(CFG_SYS_NS16550_COM3)
 #error	"Console port 3 defined but not configured."
-#elif CONFIG_CONS_INDEX == 4 && !defined(CONFIG_SYS_NS16550_COM4)
+#elif CONFIG_CONS_INDEX == 4 && !defined(CFG_SYS_NS16550_COM4)
 #error	"Console port 4 defined but not configured."
-#elif CONFIG_CONS_INDEX == 5 && !defined(CONFIG_SYS_NS16550_COM5)
+#elif CONFIG_CONS_INDEX == 5 && !defined(CFG_SYS_NS16550_COM5)
 #error	"Console port 5 defined but not configured."
-#elif CONFIG_CONS_INDEX == 6 && !defined(CONFIG_SYS_NS16550_COM6)
+#elif CONFIG_CONS_INDEX == 6 && !defined(CFG_SYS_NS16550_COM6)
 #error	"Console port 6 defined but not configured."
 #endif
 
@@ -38,33 +38,33 @@ DECLARE_GLOBAL_DATA_PTR;
  *	 the array is 0 based.
  */
 static struct ns16550 *serial_ports[6] = {
-#ifdef CONFIG_SYS_NS16550_COM1
-	(struct ns16550 *)CONFIG_SYS_NS16550_COM1,
+#ifdef CFG_SYS_NS16550_COM1
+	(struct ns16550 *)CFG_SYS_NS16550_COM1,
 #else
 	NULL,
 #endif
-#ifdef CONFIG_SYS_NS16550_COM2
-	(struct ns16550 *)CONFIG_SYS_NS16550_COM2,
+#ifdef CFG_SYS_NS16550_COM2
+	(struct ns16550 *)CFG_SYS_NS16550_COM2,
 #else
 	NULL,
 #endif
-#ifdef CONFIG_SYS_NS16550_COM3
-	(struct ns16550 *)CONFIG_SYS_NS16550_COM3,
+#ifdef CFG_SYS_NS16550_COM3
+	(struct ns16550 *)CFG_SYS_NS16550_COM3,
 #else
 	NULL,
 #endif
-#ifdef CONFIG_SYS_NS16550_COM4
-	(struct ns16550 *)CONFIG_SYS_NS16550_COM4,
+#ifdef CFG_SYS_NS16550_COM4
+	(struct ns16550 *)CFG_SYS_NS16550_COM4,
 #else
 	NULL,
 #endif
-#ifdef CONFIG_SYS_NS16550_COM5
-	(struct ns16550 *)CONFIG_SYS_NS16550_COM5,
+#ifdef CFG_SYS_NS16550_COM5
+	(struct ns16550 *)CFG_SYS_NS16550_COM5,
 #else
 	NULL,
 #endif
-#ifdef CONFIG_SYS_NS16550_COM6
-	(struct ns16550 *)CONFIG_SYS_NS16550_COM6
+#ifdef CFG_SYS_NS16550_COM6
+	(struct ns16550 *)CFG_SYS_NS16550_COM6
 #else
 	NULL
 #endif
@@ -78,7 +78,7 @@ static struct ns16550 *serial_ports[6] = {
 	{ \
 		int clock_divisor; \
 		clock_divisor = ns16550_calc_divisor(serial_ports[port-1], \
-				CONFIG_SYS_NS16550_CLK, gd->baudrate); \
+				CFG_SYS_NS16550_CLK, gd->baudrate); \
 		ns16550_init(serial_ports[port - 1], clock_divisor); \
 		return 0 ; \
 	} \
@@ -144,7 +144,7 @@ static void _serial_setbrg(const int port)
 {
 	int clock_divisor;
 
-	clock_divisor = ns16550_calc_divisor(PORT, CONFIG_SYS_NS16550_CLK,
+	clock_divisor = ns16550_calc_divisor(PORT, CFG_SYS_NS16550_CLK,
 					     gd->baudrate);
 	ns16550_reinit(PORT, clock_divisor);
 }
@@ -179,32 +179,32 @@ serial_setbrg_dev(unsigned int dev_index)
 	_serial_setbrg(dev_index);
 }
 
-#if defined(CONFIG_SYS_NS16550_COM1)
+#if defined(CFG_SYS_NS16550_COM1)
 DECLARE_ESERIAL_FUNCTIONS(1);
 struct serial_device eserial1_device =
 	INIT_ESERIAL_STRUCTURE(1, "eserial0");
 #endif
-#if defined(CONFIG_SYS_NS16550_COM2)
+#if defined(CFG_SYS_NS16550_COM2)
 DECLARE_ESERIAL_FUNCTIONS(2);
 struct serial_device eserial2_device =
 	INIT_ESERIAL_STRUCTURE(2, "eserial1");
 #endif
-#if defined(CONFIG_SYS_NS16550_COM3)
+#if defined(CFG_SYS_NS16550_COM3)
 DECLARE_ESERIAL_FUNCTIONS(3);
 struct serial_device eserial3_device =
 	INIT_ESERIAL_STRUCTURE(3, "eserial2");
 #endif
-#if defined(CONFIG_SYS_NS16550_COM4)
+#if defined(CFG_SYS_NS16550_COM4)
 DECLARE_ESERIAL_FUNCTIONS(4);
 struct serial_device eserial4_device =
 	INIT_ESERIAL_STRUCTURE(4, "eserial3");
 #endif
-#if defined(CONFIG_SYS_NS16550_COM5)
+#if defined(CFG_SYS_NS16550_COM5)
 DECLARE_ESERIAL_FUNCTIONS(5);
 struct serial_device eserial5_device =
 	INIT_ESERIAL_STRUCTURE(5, "eserial4");
 #endif
-#if defined(CONFIG_SYS_NS16550_COM6)
+#if defined(CFG_SYS_NS16550_COM6)
 DECLARE_ESERIAL_FUNCTIONS(6);
 struct serial_device eserial6_device =
 	INIT_ESERIAL_STRUCTURE(6, "eserial5");
@@ -231,22 +231,22 @@ __weak struct serial_device *default_serial_console(void)
 
 void ns16550_serial_initialize(void)
 {
-#if defined(CONFIG_SYS_NS16550_COM1)
+#if defined(CFG_SYS_NS16550_COM1)
 	serial_register(&eserial1_device);
 #endif
-#if defined(CONFIG_SYS_NS16550_COM2)
+#if defined(CFG_SYS_NS16550_COM2)
 	serial_register(&eserial2_device);
 #endif
-#if defined(CONFIG_SYS_NS16550_COM3)
+#if defined(CFG_SYS_NS16550_COM3)
 	serial_register(&eserial3_device);
 #endif
-#if defined(CONFIG_SYS_NS16550_COM4)
+#if defined(CFG_SYS_NS16550_COM4)
 	serial_register(&eserial4_device);
 #endif
-#if defined(CONFIG_SYS_NS16550_COM5)
+#if defined(CFG_SYS_NS16550_COM5)
 	serial_register(&eserial5_device);
 #endif
-#if defined(CONFIG_SYS_NS16550_COM6)
+#if defined(CFG_SYS_NS16550_COM6)
 	serial_register(&eserial6_device);
 #endif
 }
diff --git a/drivers/serial/serial_omap.c b/drivers/serial/serial_omap.c
index e9ff61a0bac5..904f7d21bf03 100644
--- a/drivers/serial/serial_omap.c
+++ b/drivers/serial/serial_omap.c
@@ -15,8 +15,8 @@
 #include <clk.h>
 #include <linux/err.h>
 
-#ifndef CONFIG_SYS_NS16550_CLK
-#define CONFIG_SYS_NS16550_CLK  0
+#ifndef CFG_SYS_NS16550_CLK
+#define CFG_SYS_NS16550_CLK  0
 #endif
 
 #ifdef CONFIG_DEBUG_UART_OMAP
@@ -128,7 +128,7 @@ static int omap_serial_of_to_plat(struct udevice *dev)
 
 	if (!plat->clock)
 		plat->clock = dev_read_u32_default(dev, "clock-frequency",
-						   CONFIG_SYS_NS16550_CLK);
+						   CFG_SYS_NS16550_CLK);
 	if (!plat->clock) {
 		debug("omap serial clock not defined\n");
 		return -EINVAL;
diff --git a/include/configs/MPC837XERDB.h b/include/configs/MPC837XERDB.h
index b8cbdc36754b..059885ecb54f 100644
--- a/include/configs/MPC837XERDB.h
+++ b/include/configs/MPC837XERDB.h
@@ -151,13 +151,13 @@
 /*
  * Serial Port
  */
-#define CONFIG_SYS_NS16550_CLK		get_bus_freq(0)
+#define CFG_SYS_NS16550_CLK		get_bus_freq(0)
 
 #define CONFIG_SYS_BAUDRATE_TABLE \
 		{300, 600, 1200, 2400, 4800, 9600, 19200, 38400, 115200}
 
-#define CONFIG_SYS_NS16550_COM1	(CONFIG_SYS_IMMR+0x4500)
-#define CONFIG_SYS_NS16550_COM2	(CONFIG_SYS_IMMR+0x4600)
+#define CFG_SYS_NS16550_COM1	(CONFIG_SYS_IMMR+0x4500)
+#define CFG_SYS_NS16550_COM2	(CONFIG_SYS_IMMR+0x4600)
 
 /* SERDES */
 #define CONFIG_FSL_SERDES
diff --git a/include/configs/MPC8548CDS.h b/include/configs/MPC8548CDS.h
index dba15dae749b..bde8fa8df4dd 100644
--- a/include/configs/MPC8548CDS.h
+++ b/include/configs/MPC8548CDS.h
@@ -235,13 +235,13 @@
 #define CONFIG_SYS_INIT_SP_OFFSET	(CONFIG_SYS_INIT_RAM_SIZE - GENERATED_GBL_DATA_SIZE)
 
 /* Serial Port */
-#define CONFIG_SYS_NS16550_CLK		get_bus_freq(0)
+#define CFG_SYS_NS16550_CLK		get_bus_freq(0)
 
 #define CONFIG_SYS_BAUDRATE_TABLE \
 	{300, 600, 1200, 2400, 4800, 9600, 19200, 38400,115200}
 
-#define CONFIG_SYS_NS16550_COM1	(CONFIG_SYS_CCSRBAR+0x4500)
-#define CONFIG_SYS_NS16550_COM2	(CONFIG_SYS_CCSRBAR+0x4600)
+#define CFG_SYS_NS16550_COM1	(CONFIG_SYS_CCSRBAR+0x4500)
+#define CFG_SYS_NS16550_COM2	(CONFIG_SYS_CCSRBAR+0x4600)
 
 /*
  * I2C
diff --git a/include/configs/P1010RDB.h b/include/configs/P1010RDB.h
index fd721f30b3aa..05c097759f62 100644
--- a/include/configs/P1010RDB.h
+++ b/include/configs/P1010RDB.h
@@ -322,13 +322,13 @@ extern unsigned long get_sdram_size(void);
 
 /* Serial Port */
 #undef	CONFIG_SERIAL_SOFTWARE_FIFO
-#define CONFIG_SYS_NS16550_CLK		get_bus_freq(0)
+#define CFG_SYS_NS16550_CLK		get_bus_freq(0)
 
 #define CONFIG_SYS_BAUDRATE_TABLE	\
 	{300, 600, 1200, 2400, 4800, 9600, 19200, 38400, 57600, 115200}
 
-#define CONFIG_SYS_NS16550_COM1	(CONFIG_SYS_CCSRBAR+0x4500)
-#define CONFIG_SYS_NS16550_COM2	(CONFIG_SYS_CCSRBAR+0x4600)
+#define CFG_SYS_NS16550_COM1	(CONFIG_SYS_CCSRBAR+0x4500)
+#define CFG_SYS_NS16550_COM2	(CONFIG_SYS_CCSRBAR+0x4600)
 
 /* I2C */
 #define I2C_PCA9557_ADDR1		0x18
diff --git a/include/configs/P2041RDB.h b/include/configs/P2041RDB.h
index 173f6205e08f..132786a42368 100644
--- a/include/configs/P2041RDB.h
+++ b/include/configs/P2041RDB.h
@@ -163,15 +163,15 @@
  * open - index 2
  * shorted - index 1
  */
-#define CONFIG_SYS_NS16550_CLK		(get_bus_freq(0)/2)
+#define CFG_SYS_NS16550_CLK		(get_bus_freq(0)/2)
 
 #define CONFIG_SYS_BAUDRATE_TABLE	\
 	{300, 600, 1200, 2400, 4800, 9600, 19200, 38400, 57600, 115200}
 
-#define CONFIG_SYS_NS16550_COM1	(CONFIG_SYS_CCSRBAR+0x11C500)
-#define CONFIG_SYS_NS16550_COM2	(CONFIG_SYS_CCSRBAR+0x11C600)
-#define CONFIG_SYS_NS16550_COM3	(CONFIG_SYS_CCSRBAR+0x11D500)
-#define CONFIG_SYS_NS16550_COM4	(CONFIG_SYS_CCSRBAR+0x11D600)
+#define CFG_SYS_NS16550_COM1	(CONFIG_SYS_CCSRBAR+0x11C500)
+#define CFG_SYS_NS16550_COM2	(CONFIG_SYS_CCSRBAR+0x11C600)
+#define CFG_SYS_NS16550_COM3	(CONFIG_SYS_CCSRBAR+0x11D500)
+#define CFG_SYS_NS16550_COM4	(CONFIG_SYS_CCSRBAR+0x11D600)
 
 /* I2C */
 
diff --git a/include/configs/SBx81LIFKW.h b/include/configs/SBx81LIFKW.h
index c99e6ba781a4..824190a41234 100644
--- a/include/configs/SBx81LIFKW.h
+++ b/include/configs/SBx81LIFKW.h
@@ -12,8 +12,8 @@
 /*
  * NS16550 Configuration
  */
-#define CONFIG_SYS_NS16550_CLK		CONFIG_SYS_TCLK
-#define CONFIG_SYS_NS16550_COM1		KW_UART0_BASE
+#define CFG_SYS_NS16550_CLK		CONFIG_SYS_TCLK
+#define CFG_SYS_NS16550_COM1		KW_UART0_BASE
 
 /*
  * Serial Port configuration
diff --git a/include/configs/SBx81LIFXCAT.h b/include/configs/SBx81LIFXCAT.h
index 8b43fe0c9939..e67da1fe1dc2 100644
--- a/include/configs/SBx81LIFXCAT.h
+++ b/include/configs/SBx81LIFXCAT.h
@@ -12,8 +12,8 @@
 /*
  * NS16550 Configuration
  */
-#define CONFIG_SYS_NS16550_CLK		CONFIG_SYS_TCLK
-#define CONFIG_SYS_NS16550_COM1		KW_UART0_BASE
+#define CFG_SYS_NS16550_CLK		CONFIG_SYS_TCLK
+#define CFG_SYS_NS16550_COM1		KW_UART0_BASE
 
 /*
  * Serial Port configuration
diff --git a/include/configs/T102xRDB.h b/include/configs/T102xRDB.h
index 7cb10b205db1..b8f3d70e5953 100644
--- a/include/configs/T102xRDB.h
+++ b/include/configs/T102xRDB.h
@@ -294,15 +294,15 @@
 #define CONFIG_SYS_INIT_SP_OFFSET	(CONFIG_SYS_INIT_RAM_SIZE - GENERATED_GBL_DATA_SIZE)
 
 /* Serial Port */
-#define CONFIG_SYS_NS16550_CLK		(get_bus_freq(0)/2)
+#define CFG_SYS_NS16550_CLK		(get_bus_freq(0)/2)
 
 #define CONFIG_SYS_BAUDRATE_TABLE	\
 	{300, 600, 1200, 2400, 4800, 9600, 19200, 38400, 57600, 115200}
 
-#define CONFIG_SYS_NS16550_COM1	(CONFIG_SYS_CCSRBAR+0x11C500)
-#define CONFIG_SYS_NS16550_COM2	(CONFIG_SYS_CCSRBAR+0x11C600)
-#define CONFIG_SYS_NS16550_COM3	(CONFIG_SYS_CCSRBAR+0x11D500)
-#define CONFIG_SYS_NS16550_COM4	(CONFIG_SYS_CCSRBAR+0x11D600)
+#define CFG_SYS_NS16550_COM1	(CONFIG_SYS_CCSRBAR+0x11C500)
+#define CFG_SYS_NS16550_COM2	(CONFIG_SYS_CCSRBAR+0x11C600)
+#define CFG_SYS_NS16550_COM3	(CONFIG_SYS_CCSRBAR+0x11D500)
+#define CFG_SYS_NS16550_COM4	(CONFIG_SYS_CCSRBAR+0x11D600)
 
 /* I2C */
 
diff --git a/include/configs/T104xRDB.h b/include/configs/T104xRDB.h
index 3fa2d01dcc2a..777a64eceee0 100644
--- a/include/configs/T104xRDB.h
+++ b/include/configs/T104xRDB.h
@@ -267,15 +267,15 @@
  * open - index 2
  * shorted - index 1
  */
-#define CONFIG_SYS_NS16550_CLK		(get_bus_freq(0)/2)
+#define CFG_SYS_NS16550_CLK		(get_bus_freq(0)/2)
 
 #define CONFIG_SYS_BAUDRATE_TABLE	\
 	{300, 600, 1200, 2400, 4800, 9600, 19200, 38400, 57600, 115200}
 
-#define CONFIG_SYS_NS16550_COM1	(CONFIG_SYS_CCSRBAR+0x11C500)
-#define CONFIG_SYS_NS16550_COM2	(CONFIG_SYS_CCSRBAR+0x11C600)
-#define CONFIG_SYS_NS16550_COM3	(CONFIG_SYS_CCSRBAR+0x11D500)
-#define CONFIG_SYS_NS16550_COM4	(CONFIG_SYS_CCSRBAR+0x11D600)
+#define CFG_SYS_NS16550_COM1	(CONFIG_SYS_CCSRBAR+0x11C500)
+#define CFG_SYS_NS16550_COM2	(CONFIG_SYS_CCSRBAR+0x11C600)
+#define CFG_SYS_NS16550_COM3	(CONFIG_SYS_CCSRBAR+0x11D500)
+#define CFG_SYS_NS16550_COM4	(CONFIG_SYS_CCSRBAR+0x11D600)
 
 /* I2C bus multiplexer */
 #define I2C_MUX_PCA_ADDR                0x70
diff --git a/include/configs/T208xQDS.h b/include/configs/T208xQDS.h
index c5a28fadb004..710f105cfad9 100644
--- a/include/configs/T208xQDS.h
+++ b/include/configs/T208xQDS.h
@@ -269,13 +269,13 @@
 /*
  * Serial Port
  */
-#define CONFIG_SYS_NS16550_CLK		(get_bus_freq(0)/2)
+#define CFG_SYS_NS16550_CLK		(get_bus_freq(0)/2)
 #define CONFIG_SYS_BAUDRATE_TABLE	\
 	{300, 600, 1200, 2400, 4800, 9600, 19200, 38400, 57600, 115200}
-#define CONFIG_SYS_NS16550_COM1 (CONFIG_SYS_CCSRBAR+0x11C500)
-#define CONFIG_SYS_NS16550_COM2 (CONFIG_SYS_CCSRBAR+0x11C600)
-#define CONFIG_SYS_NS16550_COM3 (CONFIG_SYS_CCSRBAR+0x11D500)
-#define CONFIG_SYS_NS16550_COM4 (CONFIG_SYS_CCSRBAR+0x11D600)
+#define CFG_SYS_NS16550_COM1 (CONFIG_SYS_CCSRBAR+0x11C500)
+#define CFG_SYS_NS16550_COM2 (CONFIG_SYS_CCSRBAR+0x11C600)
+#define CFG_SYS_NS16550_COM3 (CONFIG_SYS_CCSRBAR+0x11D500)
+#define CFG_SYS_NS16550_COM4 (CONFIG_SYS_CCSRBAR+0x11D600)
 
 /*
  * I2C
diff --git a/include/configs/T208xRDB.h b/include/configs/T208xRDB.h
index 795120c02a87..4c60364f7e78 100644
--- a/include/configs/T208xRDB.h
+++ b/include/configs/T208xRDB.h
@@ -229,13 +229,13 @@
 /*
  * Serial Port
  */
-#define CONFIG_SYS_NS16550_CLK		(get_bus_freq(0)/2)
+#define CFG_SYS_NS16550_CLK		(get_bus_freq(0)/2)
 #define CONFIG_SYS_BAUDRATE_TABLE	\
 	{300, 600, 1200, 2400, 4800, 9600, 19200, 38400, 57600, 115200}
-#define CONFIG_SYS_NS16550_COM1 (CONFIG_SYS_CCSRBAR+0x11C500)
-#define CONFIG_SYS_NS16550_COM2 (CONFIG_SYS_CCSRBAR+0x11C600)
-#define CONFIG_SYS_NS16550_COM3 (CONFIG_SYS_CCSRBAR+0x11D500)
-#define CONFIG_SYS_NS16550_COM4 (CONFIG_SYS_CCSRBAR+0x11D600)
+#define CFG_SYS_NS16550_COM1 (CONFIG_SYS_CCSRBAR+0x11C500)
+#define CFG_SYS_NS16550_COM2 (CONFIG_SYS_CCSRBAR+0x11C600)
+#define CFG_SYS_NS16550_COM3 (CONFIG_SYS_CCSRBAR+0x11D500)
+#define CFG_SYS_NS16550_COM4 (CONFIG_SYS_CCSRBAR+0x11D600)
 
 /*
  * I2C
diff --git a/include/configs/T4240RDB.h b/include/configs/T4240RDB.h
index e3cbc649fa19..ba4a989fc5f7 100644
--- a/include/configs/T4240RDB.h
+++ b/include/configs/T4240RDB.h
@@ -89,15 +89,15 @@
  * open - index 2
  * shorted - index 1
  */
-#define CONFIG_SYS_NS16550_CLK		(get_bus_freq(0)/2)
+#define CFG_SYS_NS16550_CLK		(get_bus_freq(0)/2)
 
 #define CONFIG_SYS_BAUDRATE_TABLE	\
 	{300, 600, 1200, 2400, 4800, 9600, 19200, 38400, 57600, 115200}
 
-#define CONFIG_SYS_NS16550_COM1	(CONFIG_SYS_CCSRBAR+0x11C500)
-#define CONFIG_SYS_NS16550_COM2	(CONFIG_SYS_CCSRBAR+0x11C600)
-#define CONFIG_SYS_NS16550_COM3	(CONFIG_SYS_CCSRBAR+0x11D500)
-#define CONFIG_SYS_NS16550_COM4	(CONFIG_SYS_CCSRBAR+0x11D600)
+#define CFG_SYS_NS16550_COM1	(CONFIG_SYS_CCSRBAR+0x11C500)
+#define CFG_SYS_NS16550_COM2	(CONFIG_SYS_CCSRBAR+0x11C600)
+#define CFG_SYS_NS16550_COM3	(CONFIG_SYS_CCSRBAR+0x11D500)
+#define CFG_SYS_NS16550_COM4	(CONFIG_SYS_CCSRBAR+0x11D600)
 
 /* I2C */
 
diff --git a/include/configs/am335x_evm.h b/include/configs/am335x_evm.h
index 13b1ff3bce6e..25d9c96e164f 100644
--- a/include/configs/am335x_evm.h
+++ b/include/configs/am335x_evm.h
@@ -158,12 +158,12 @@
 #endif
 
 /* NS16550 Configuration */
-#define CONFIG_SYS_NS16550_COM1		0x44e09000	/* Base EVM has UART0 */
-#define CONFIG_SYS_NS16550_COM2		0x48022000	/* UART1 */
-#define CONFIG_SYS_NS16550_COM3		0x48024000	/* UART2 */
-#define CONFIG_SYS_NS16550_COM4		0x481a6000	/* UART3 */
-#define CONFIG_SYS_NS16550_COM5		0x481a8000	/* UART4 */
-#define CONFIG_SYS_NS16550_COM6		0x481aa000	/* UART5 */
+#define CFG_SYS_NS16550_COM1		0x44e09000	/* Base EVM has UART0 */
+#define CFG_SYS_NS16550_COM2		0x48022000	/* UART1 */
+#define CFG_SYS_NS16550_COM3		0x48024000	/* UART2 */
+#define CFG_SYS_NS16550_COM4		0x481a6000	/* UART3 */
+#define CFG_SYS_NS16550_COM5		0x481a8000	/* UART4 */
+#define CFG_SYS_NS16550_COM6		0x481aa000	/* UART5 */
 
 /* PMIC support */
 #define CONFIG_POWER_TPS65910
diff --git a/include/configs/am335x_guardian.h b/include/configs/am335x_guardian.h
index cb649b598fed..7c5e7ce475ef 100644
--- a/include/configs/am335x_guardian.h
+++ b/include/configs/am335x_guardian.h
@@ -83,12 +83,12 @@
 #define CONSOLE_COLOR_RED 0x001F
 
 /* NS16550 Configuration */
-#define CONFIG_SYS_NS16550_COM1		0x44e09000	/* UART0 */
-#define CONFIG_SYS_NS16550_COM2		0x48022000	/* UART1 */
-#define CONFIG_SYS_NS16550_COM3		0x48024000	/* UART2 */
-#define CONFIG_SYS_NS16550_COM4		0x481a6000	/* UART3 */
-#define CONFIG_SYS_NS16550_COM5		0x481a8000	/* UART4 */
-#define CONFIG_SYS_NS16550_COM6		0x481aa000	/* UART5 */
+#define CFG_SYS_NS16550_COM1		0x44e09000	/* UART0 */
+#define CFG_SYS_NS16550_COM2		0x48022000	/* UART1 */
+#define CFG_SYS_NS16550_COM3		0x48024000	/* UART2 */
+#define CFG_SYS_NS16550_COM4		0x481a6000	/* UART3 */
+#define CFG_SYS_NS16550_COM5		0x481a8000	/* UART4 */
+#define CFG_SYS_NS16550_COM6		0x481aa000	/* UART5 */
 
 #ifdef CONFIG_MTD_RAW_NAND
 #define CFG_SYS_NAND_ECCPOS  {   2,   3,   4,   5,   6,   7,   8,   9, \
diff --git a/include/configs/am335x_igep003x.h b/include/configs/am335x_igep003x.h
index b7b1cb0cfe19..abd868c14538 100644
--- a/include/configs/am335x_igep003x.h
+++ b/include/configs/am335x_igep003x.h
@@ -88,7 +88,7 @@
 			"echo WARNING: Could not determine device tree to use; fi; \0"
 
 /* NS16550 Configuration */
-#define CONFIG_SYS_NS16550_COM1		0x44e09000	/* UART0 */
+#define CFG_SYS_NS16550_COM1		0x44e09000	/* UART0 */
 
 /* Ethernet support */
 
diff --git a/include/configs/am335x_shc.h b/include/configs/am335x_shc.h
index 08bae9b886f2..452887d6995c 100644
--- a/include/configs/am335x_shc.h
+++ b/include/configs/am335x_shc.h
@@ -136,11 +136,11 @@
 #endif /* Regular Boot */
 
 /* NS16550 Configuration */
-#define CONFIG_SYS_NS16550_COM1		0x44e09000	/* UART0 */
-#define CONFIG_SYS_NS16550_COM2		0x48022000	/* UART1 */
-#define CONFIG_SYS_NS16550_COM3		0x48024000	/* UART2 */
-#define CONFIG_SYS_NS16550_COM4		0x481a6000	/* UART3 */
-#define CONFIG_SYS_NS16550_COM5		0x481a8000	/* UART4 */
-#define CONFIG_SYS_NS16550_COM6		0x481aa000	/* UART5 */
+#define CFG_SYS_NS16550_COM1		0x44e09000	/* UART0 */
+#define CFG_SYS_NS16550_COM2		0x48022000	/* UART1 */
+#define CFG_SYS_NS16550_COM3		0x48024000	/* UART2 */
+#define CFG_SYS_NS16550_COM4		0x481a6000	/* UART3 */
+#define CFG_SYS_NS16550_COM5		0x481a8000	/* UART4 */
+#define CFG_SYS_NS16550_COM6		0x481aa000	/* UART5 */
 
 #endif	/* ! __CONFIG_AM335X_SHC_H */
diff --git a/include/configs/am335x_sl50.h b/include/configs/am335x_sl50.h
index 7df5f1405512..4af9edafca8f 100644
--- a/include/configs/am335x_sl50.h
+++ b/include/configs/am335x_sl50.h
@@ -36,12 +36,12 @@
 	BOOTENV
 
 /* NS16550 Configuration */
-#define CONFIG_SYS_NS16550_COM1		0x44e09000	/* Base EVM has UART0 */
-#define CONFIG_SYS_NS16550_COM2		0x48022000	/* UART1 */
-#define CONFIG_SYS_NS16550_COM3		0x48024000	/* UART2 */
-#define CONFIG_SYS_NS16550_COM4		0x481a6000	/* UART3 */
-#define CONFIG_SYS_NS16550_COM5		0x481a8000	/* UART4 */
-#define CONFIG_SYS_NS16550_COM6		0x481aa000	/* UART5 */
+#define CFG_SYS_NS16550_COM1		0x44e09000	/* Base EVM has UART0 */
+#define CFG_SYS_NS16550_COM2		0x48022000	/* UART1 */
+#define CFG_SYS_NS16550_COM3		0x48024000	/* UART2 */
+#define CFG_SYS_NS16550_COM4		0x481a6000	/* UART3 */
+#define CFG_SYS_NS16550_COM5		0x481a8000	/* UART4 */
+#define CFG_SYS_NS16550_COM6		0x481aa000	/* UART5 */
 
 /* PMIC support */
 #define CONFIG_POWER_TPS65910
diff --git a/include/configs/am43xx_evm.h b/include/configs/am43xx_evm.h
index b61c8005c33f..4ff8528cf8ad 100644
--- a/include/configs/am43xx_evm.h
+++ b/include/configs/am43xx_evm.h
@@ -14,7 +14,7 @@
 #include <asm/arch/omap.h>
 
 /* NS16550 Configuration */
-#define CONFIG_SYS_NS16550_CLK		48000000
+#define CFG_SYS_NS16550_CLK		48000000
 
 /* I2C Configuration */
 
@@ -41,7 +41,7 @@
 #define V_SCLK				(V_OSCK)
 
 /* NS16550 Configuration */
-#define CONFIG_SYS_NS16550_COM1		0x44e09000	/* Base EVM has UART0 */
+#define CFG_SYS_NS16550_COM1		0x44e09000	/* Base EVM has UART0 */
 
 #ifndef CONFIG_SPL_BUILD
 /* USB Device Firmware Update support */
diff --git a/include/configs/am57xx_evm.h b/include/configs/am57xx_evm.h
index d8b0531673f1..c3b6a3fbda2c 100644
--- a/include/configs/am57xx_evm.h
+++ b/include/configs/am57xx_evm.h
@@ -16,9 +16,9 @@
 
 #define CONFIG_IODELAY_RECALIBRATION
 
-#define CONFIG_SYS_NS16550_COM1		UART1_BASE	/* Base EVM has UART0 */
-#define CONFIG_SYS_NS16550_COM2		UART2_BASE	/* UART2 */
-#define CONFIG_SYS_NS16550_COM3		UART3_BASE	/* UART3 */
+#define CFG_SYS_NS16550_COM1		UART1_BASE	/* Base EVM has UART0 */
+#define CFG_SYS_NS16550_COM2		UART2_BASE	/* UART2 */
+#define CFG_SYS_NS16550_COM3		UART3_BASE	/* UART3 */
 
 #define CONFIG_SYS_OMAP_ABE_SYSCK
 
diff --git a/include/configs/ap143.h b/include/configs/ap143.h
index 0eed8db23bd9..3114cf0c4fba 100644
--- a/include/configs/ap143.h
+++ b/include/configs/ap143.h
@@ -14,7 +14,7 @@
 /*
  * Serial Port
  */
-#define CONFIG_SYS_NS16550_CLK          25000000
+#define CFG_SYS_NS16550_CLK          25000000
 
 /* Miscellaneous configurable options */
 
diff --git a/include/configs/ap152.h b/include/configs/ap152.h
index 712471111909..f0674456fd0c 100644
--- a/include/configs/ap152.h
+++ b/include/configs/ap152.h
@@ -14,7 +14,7 @@
 /*
  * Serial Port
  */
-#define CONFIG_SYS_NS16550_CLK          25000000
+#define CFG_SYS_NS16550_CLK          25000000
 
 /* Miscellaneous configurable options */
 
diff --git a/include/configs/apalis-tk1.h b/include/configs/apalis-tk1.h
index 6a4092a83e2e..f0a02ae17953 100644
--- a/include/configs/apalis-tk1.h
+++ b/include/configs/apalis-tk1.h
@@ -14,7 +14,7 @@
 
 /* Board-specific serial config */
 #define CONFIG_TEGRA_ENABLE_UARTA
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
 
 #define FDT_MODULE			"apalis-v1.2"
 #define FDT_MODULE_V1_0			"apalis"
diff --git a/include/configs/apalis_t30.h b/include/configs/apalis_t30.h
index 84bd88f835ae..4f00b3bad3f4 100644
--- a/include/configs/apalis_t30.h
+++ b/include/configs/apalis_t30.h
@@ -21,7 +21,7 @@
  * Apalis UART4: NVIDIA UARTC
  */
 #define CONFIG_TEGRA_ENABLE_UARTA
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
 
 #define UBOOT_UPDATE \
 	"uboot_hwpart=1\0" \
diff --git a/include/configs/ax25-ae350.h b/include/configs/ax25-ae350.h
index 7224bd8d1f49..e3b6956eb5a2 100644
--- a/include/configs/ax25-ae350.h
+++ b/include/configs/ax25-ae350.h
@@ -33,7 +33,7 @@
 /*
  * Serial console configuration
  */
-#define CONFIG_SYS_NS16550_CLK		19660800
+#define CFG_SYS_NS16550_CLK		19660800
 
 /* Init Stack Pointer */
 
diff --git a/include/configs/axs10x.h b/include/configs/axs10x.h
index c0429ae15c4c..1932713f453a 100644
--- a/include/configs/axs10x.h
+++ b/include/configs/axs10x.h
@@ -26,7 +26,7 @@
 /*
  * UART configuration
  */
-#define CONFIG_SYS_NS16550_CLK		33333333
+#define CFG_SYS_NS16550_CLK		33333333
 
 /*
  * Ethernet PHY configuration
diff --git a/include/configs/baltos.h b/include/configs/baltos.h
index 31f107a465c1..f29729d09bac 100644
--- a/include/configs/baltos.h
+++ b/include/configs/baltos.h
@@ -181,12 +181,12 @@
 	/*DFUARGS*/
 
 /* NS16550 Configuration */
-#define CONFIG_SYS_NS16550_COM1		0x44e09000	/* Base EVM has UART0 */
-#define CONFIG_SYS_NS16550_COM2		0x48022000	/* UART1 */
-#define CONFIG_SYS_NS16550_COM3		0x48024000	/* UART2 */
-#define CONFIG_SYS_NS16550_COM4		0x481a6000	/* UART3 */
-#define CONFIG_SYS_NS16550_COM5		0x481a8000	/* UART4 */
-#define CONFIG_SYS_NS16550_COM6		0x481aa000	/* UART5 */
+#define CFG_SYS_NS16550_COM1		0x44e09000	/* Base EVM has UART0 */
+#define CFG_SYS_NS16550_COM2		0x48022000	/* UART1 */
+#define CFG_SYS_NS16550_COM3		0x48024000	/* UART2 */
+#define CFG_SYS_NS16550_COM4		0x481a6000	/* UART3 */
+#define CFG_SYS_NS16550_COM5		0x481a8000	/* UART4 */
+#define CFG_SYS_NS16550_COM6		0x481aa000	/* UART5 */
 
 /* PMIC support */
 #define CONFIG_POWER_TPS65910
diff --git a/include/configs/bcm7260.h b/include/configs/bcm7260.h
index 1bae49e15f35..cba109b74a9f 100644
--- a/include/configs/bcm7260.h
+++ b/include/configs/bcm7260.h
@@ -10,7 +10,7 @@
 #ifndef __CONFIG_H
 #define __CONFIG_H
 
-#define CONFIG_SYS_NS16550_COM1	0xf040c000
+#define CFG_SYS_NS16550_COM1	0xf040c000
 
 #define CONFIG_SYS_INIT_RAM_ADDR	0x10200000
 
diff --git a/include/configs/bcm7445.h b/include/configs/bcm7445.h
index 4b41dc220b15..a07f1b7ad0f1 100644
--- a/include/configs/bcm7445.h
+++ b/include/configs/bcm7445.h
@@ -10,7 +10,7 @@
 #ifndef __CONFIG_H
 #define __CONFIG_H
 
-#define CONFIG_SYS_NS16550_COM1	0xf040ab00
+#define CFG_SYS_NS16550_COM1	0xf040ab00
 
 #define CONFIG_SYS_INIT_RAM_ADDR	0x80200000
 
diff --git a/include/configs/bcm_ns3.h b/include/configs/bcm_ns3.h
index 795de469384c..76189a4d31f7 100644
--- a/include/configs/bcm_ns3.h
+++ b/include/configs/bcm_ns3.h
@@ -26,7 +26,7 @@
 /* 12MB Malloc size */
 
 /* console configuration */
-#define CONFIG_SYS_NS16550_CLK		25000000
+#define CFG_SYS_NS16550_CLK		25000000
 
 /*
  * Increase max uncompressed/gunzip size, keeping size same as EMMC linux
diff --git a/include/configs/bcmstb.h b/include/configs/bcmstb.h
index 481baff11d9a..9f51b9ca59d2 100644
--- a/include/configs/bcmstb.h
+++ b/include/configs/bcmstb.h
@@ -97,7 +97,7 @@ extern phys_addr_t prior_stage_fdt_address;
  */
 #define V_NS16550_CLK			81000000
 
-#define CONFIG_SYS_NS16550_CLK		V_NS16550_CLK
+#define CFG_SYS_NS16550_CLK		V_NS16550_CLK
 
 /*
  * Serial console configuration.
diff --git a/include/configs/beaver.h b/include/configs/beaver.h
index 1d51bb4e4c48..6b5f650811b8 100644
--- a/include/configs/beaver.h
+++ b/include/configs/beaver.h
@@ -18,7 +18,7 @@
 
 /* Board-specific serial config */
 #define CONFIG_TEGRA_ENABLE_UARTA
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
 
 /* SPI */
 #define CONFIG_TEGRA_SLINK_CTRLS       6
diff --git a/include/configs/bur_am335x_common.h b/include/configs/bur_am335x_common.h
index 773ce3f6a6f8..1bf6baf75c23 100644
--- a/include/configs/bur_am335x_common.h
+++ b/include/configs/bur_am335x_common.h
@@ -14,8 +14,8 @@
 
 /* legacy #defines for non DM bur-board */
 #ifndef CONFIG_DM
-#define CONFIG_SYS_NS16550_CLK		(48000000)
-#define CONFIG_SYS_NS16550_COM1		0x44e09000
+#define CFG_SYS_NS16550_CLK		(48000000)
+#define CFG_SYS_NS16550_COM1		0x44e09000
 
 #endif /* CONFIG_DM */
 
diff --git a/include/configs/cardhu.h b/include/configs/cardhu.h
index f3416b534b23..35c5a4f12261 100644
--- a/include/configs/cardhu.h
+++ b/include/configs/cardhu.h
@@ -22,7 +22,7 @@
 
 /* Board-specific serial config */
 #define CONFIG_TEGRA_ENABLE_UARTA
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
 
 /* SPI */
 #define CONFIG_TEGRA_SLINK_CTRLS       6
diff --git a/include/configs/cei-tk1-som.h b/include/configs/cei-tk1-som.h
index 0672b7dbbe93..55e2d744c4a0 100644
--- a/include/configs/cei-tk1-som.h
+++ b/include/configs/cei-tk1-som.h
@@ -20,7 +20,7 @@
 
 /* Board-specific serial config */
 #define CONFIG_TEGRA_ENABLE_UARTD
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
 
 /* SPI */
 #define CONFIG_SPI_FLASH_SIZE		(4 << 20)
diff --git a/include/configs/chiliboard.h b/include/configs/chiliboard.h
index bfa076b5cc98..1e5154af0a15 100644
--- a/include/configs/chiliboard.h
+++ b/include/configs/chiliboard.h
@@ -97,12 +97,12 @@
 	NANDARGS
 
 /* NS16550 Configuration */
-#define CONFIG_SYS_NS16550_COM1		0x44e09000	/* UART0 */
-#define CONFIG_SYS_NS16550_COM2		0x48022000	/* UART1 */
-#define CONFIG_SYS_NS16550_COM3		0x48024000	/* UART2 */
-#define CONFIG_SYS_NS16550_COM4		0x481a6000	/* UART3 */
-#define CONFIG_SYS_NS16550_COM5		0x481a8000	/* UART4 */
-#define CONFIG_SYS_NS16550_COM6		0x481aa000	/* UART5 */
+#define CFG_SYS_NS16550_COM1		0x44e09000	/* UART0 */
+#define CFG_SYS_NS16550_COM2		0x48022000	/* UART1 */
+#define CFG_SYS_NS16550_COM3		0x48024000	/* UART2 */
+#define CFG_SYS_NS16550_COM4		0x481a6000	/* UART3 */
+#define CFG_SYS_NS16550_COM5		0x481a8000	/* UART4 */
+#define CFG_SYS_NS16550_COM6		0x481aa000	/* UART5 */
 
 /* SPL */
 
diff --git a/include/configs/ci20.h b/include/configs/ci20.h
index 63dac1d4a79d..b7511adc09ad 100644
--- a/include/configs/ci20.h
+++ b/include/configs/ci20.h
@@ -15,7 +15,7 @@
 #define CONFIG_SYS_INIT_SP_OFFSET	0x400000
 
 /* NS16550-ish UARTs */
-#define CONFIG_SYS_NS16550_CLK		48000000
+#define CFG_SYS_NS16550_CLK		48000000
 
 /* Ethernet: davicom DM9000 */
 #define CONFIG_DM9000_BASE		0xb6000000
diff --git a/include/configs/cm_t43.h b/include/configs/cm_t43.h
index 0641d5c0a238..8f058213e9e7 100644
--- a/include/configs/cm_t43.h
+++ b/include/configs/cm_t43.h
@@ -14,8 +14,8 @@
 #include <asm/arch/omap.h>
 
 /* Serial support */
-#define CONFIG_SYS_NS16550_CLK		48000000
-#define CONFIG_SYS_NS16550_COM1		0x44e09000
+#define CFG_SYS_NS16550_CLK		48000000
+#define CFG_SYS_NS16550_COM1		0x44e09000
 
 /* NAND support */
 #define CFG_SYS_NAND_ECCSIZE		512
diff --git a/include/configs/colibri_t20.h b/include/configs/colibri_t20.h
index b758086b86d5..2ba3c3bc87db 100644
--- a/include/configs/colibri_t20.h
+++ b/include/configs/colibri_t20.h
@@ -13,7 +13,7 @@
 /* Board-specific serial config */
 #define CONFIG_TEGRA_ENABLE_UARTA
 #define CONFIG_TEGRA_UARTA_SDIO1
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
 
 /* NAND support */
 
diff --git a/include/configs/colibri_t30.h b/include/configs/colibri_t30.h
index c9d384e2bdbe..ffed71a2e828 100644
--- a/include/configs/colibri_t30.h
+++ b/include/configs/colibri_t30.h
@@ -22,7 +22,7 @@
  * Colibri UART-C: NVIDIA UARTB
  */
 #define CONFIG_TEGRA_ENABLE_UARTA
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
 
 #define UBOOT_UPDATE \
 	"uboot_hwpart=1\0" \
diff --git a/include/configs/da850evm.h b/include/configs/da850evm.h
index f8ba4e828194..4f0188dd19ed 100644
--- a/include/configs/da850evm.h
+++ b/include/configs/da850evm.h
@@ -94,7 +94,7 @@
 /*
  * Serial Driver info
  */
-#define CONFIG_SYS_NS16550_CLK	clk_get(DAVINCI_UART2_CLKID)
+#define CFG_SYS_NS16550_CLK	clk_get(DAVINCI_UART2_CLKID)
 
 #define CONFIG_SYS_SPI_CLK		clk_get(DAVINCI_SPI1_CLKID)
 
diff --git a/include/configs/dalmore.h b/include/configs/dalmore.h
index e03a24adca4a..24cf554649ba 100644
--- a/include/configs/dalmore.h
+++ b/include/configs/dalmore.h
@@ -15,7 +15,7 @@
 
 /* Board-specific serial config */
 #define CONFIG_TEGRA_ENABLE_UARTD
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
 
 /* Environment in eMMC, at the end of 2nd "boot sector" */
 
diff --git a/include/configs/dra7xx_evm.h b/include/configs/dra7xx_evm.h
index 93201be485d6..e1d18a778306 100644
--- a/include/configs/dra7xx_evm.h
+++ b/include/configs/dra7xx_evm.h
@@ -27,9 +27,9 @@
 #elif (CONFIG_CONS_INDEX == 3)
 #define CONSOLEDEV			"ttyS2"
 #endif
-#define CONFIG_SYS_NS16550_COM1		UART1_BASE	/* Base EVM has UART0 */
-#define CONFIG_SYS_NS16550_COM2		UART2_BASE	/* UART2 */
-#define CONFIG_SYS_NS16550_COM3		UART3_BASE	/* UART3 */
+#define CFG_SYS_NS16550_COM1		UART1_BASE	/* Base EVM has UART0 */
+#define CFG_SYS_NS16550_COM2		UART2_BASE	/* UART2 */
+#define CFG_SYS_NS16550_COM3		UART3_BASE	/* UART3 */
 
 #define CONFIG_SYS_OMAP_ABE_SYSCK
 
diff --git a/include/configs/gardena-smart-gateway-mt7688.h b/include/configs/gardena-smart-gateway-mt7688.h
index 0d61724db8c4..a1400eba1ada 100644
--- a/include/configs/gardena-smart-gateway-mt7688.h
+++ b/include/configs/gardena-smart-gateway-mt7688.h
@@ -20,8 +20,8 @@
 
 /* Serial SPL */
 #if defined(CONFIG_SPL_BUILD) && defined(CONFIG_SPL_SERIAL)
-#define CONFIG_SYS_NS16550_CLK		40000000
-#define CONFIG_SYS_NS16550_COM1		0xb0000c00
+#define CFG_SYS_NS16550_CLK		40000000
+#define CFG_SYS_NS16550_COM1		0xb0000c00
 #endif
 
 /* UART */
diff --git a/include/configs/harmony.h b/include/configs/harmony.h
index fe4b02c0ce2c..211dab4d2337 100644
--- a/include/configs/harmony.h
+++ b/include/configs/harmony.h
@@ -17,10 +17,10 @@
 #define CONFIG_TEGRA_ENABLE_UARTD
 
 /* UARTD: keyboard satellite board UART, default */
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
 #ifdef CONFIG_TEGRA_ENABLE_UARTA
 /* UARTA: debug board UART */
-#define CONFIG_SYS_NS16550_COM2		NV_PA_APB_UARTA_BASE
+#define CFG_SYS_NS16550_COM2		NV_PA_APB_UARTA_BASE
 #endif
 
 /* NAND support */
diff --git a/include/configs/hsdk-4xd.h b/include/configs/hsdk-4xd.h
index bfc0fa5c442c..1d7b171da75a 100644
--- a/include/configs/hsdk-4xd.h
+++ b/include/configs/hsdk-4xd.h
@@ -28,7 +28,7 @@
 /*
  * UART configuration
  */
-#define CONFIG_SYS_NS16550_CLK		33330000
+#define CFG_SYS_NS16550_CLK		33330000
 
 /*
  * Ethernet PHY configuration
diff --git a/include/configs/hsdk.h b/include/configs/hsdk.h
index ce3cb20732db..9e092e16ea04 100644
--- a/include/configs/hsdk.h
+++ b/include/configs/hsdk.h
@@ -27,7 +27,7 @@
 /*
  * UART configuration
  */
-#define CONFIG_SYS_NS16550_CLK		33330000
+#define CFG_SYS_NS16550_CLK		33330000
 
 /*
  * Ethernet PHY configuration
diff --git a/include/configs/jetson-tk1.h b/include/configs/jetson-tk1.h
index 69aa55f86c5f..b846889541c7 100644
--- a/include/configs/jetson-tk1.h
+++ b/include/configs/jetson-tk1.h
@@ -16,7 +16,7 @@
 
 /* Board-specific serial config */
 #define CONFIG_TEGRA_ENABLE_UARTD
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
 
 /* Environment in eMMC, at the end of 2nd "boot sector" */
 
diff --git a/include/configs/km/pg-wcom-ls102xa.h b/include/configs/km/pg-wcom-ls102xa.h
index 7acdb0fa038e..57b0fc906979 100644
--- a/include/configs/km/pg-wcom-ls102xa.h
+++ b/include/configs/km/pg-wcom-ls102xa.h
@@ -148,7 +148,7 @@
 /*
  * Serial Port
  */
-#define CONFIG_SYS_NS16550_CLK		get_serial_clock()
+#define CFG_SYS_NS16550_CLK		get_serial_clock()
 
 /*
  * I2C
diff --git a/include/configs/kmcent2.h b/include/configs/kmcent2.h
index 30ba6065253e..e6e54fba898b 100644
--- a/include/configs/kmcent2.h
+++ b/include/configs/kmcent2.h
@@ -330,8 +330,8 @@
  * Retain non-DM serial port for debug purposes.
  */
 #if !defined(CONFIG_DM_SERIAL)
-#define CONFIG_SYS_NS16550_CLK		(get_bus_freq(0) / 2)
-#define CONFIG_SYS_NS16550_COM1	(CONFIG_SYS_CCSRBAR + 0x11C500)
+#define CFG_SYS_NS16550_CLK		(get_bus_freq(0) / 2)
+#define CFG_SYS_NS16550_COM1	(CONFIG_SYS_CCSRBAR + 0x11C500)
 #endif
 
 #ifndef __ASSEMBLY__
diff --git a/include/configs/kontron_sl28.h b/include/configs/kontron_sl28.h
index 38860bfd5ca8..7ed1f153c232 100644
--- a/include/configs/kontron_sl28.h
+++ b/include/configs/kontron_sl28.h
@@ -35,7 +35,7 @@
 #define CONFIG_MALLOC_F_ADDR		CFG_SYS_FSL_OCRAM_BASE
 
 /* serial port */
-#define CONFIG_SYS_NS16550_CLK          (get_bus_freq(0) / 2)
+#define CFG_SYS_NS16550_CLK          (get_bus_freq(0) / 2)
 
 /* SPL */
 
diff --git a/include/configs/legoev3.h b/include/configs/legoev3.h
index 5434c4f7679f..1f642fbecc3c 100644
--- a/include/configs/legoev3.h
+++ b/include/configs/legoev3.h
@@ -36,7 +36,7 @@
 /*
  * Serial Driver info
  */
-#define CONFIG_SYS_NS16550_CLK	clk_get(DAVINCI_UART2_CLKID)
+#define CFG_SYS_NS16550_CLK	clk_get(DAVINCI_UART2_CLKID)
 
 #define CONFIG_SYS_SPI_CLK		clk_get(DAVINCI_SPI0_CLKID)
 
diff --git a/include/configs/linkit-smart-7688.h b/include/configs/linkit-smart-7688.h
index b9c853d7dfef..28372d41590a 100644
--- a/include/configs/linkit-smart-7688.h
+++ b/include/configs/linkit-smart-7688.h
@@ -20,8 +20,8 @@
 
 /* Serial SPL */
 #if defined(CONFIG_SPL_BUILD) && defined(CONFIG_SPL_SERIAL)
-#define CONFIG_SYS_NS16550_CLK		40000000
-#define CONFIG_SYS_NS16550_COM3		0xb0000e00
+#define CFG_SYS_NS16550_CLK		40000000
+#define CFG_SYS_NS16550_COM3		0xb0000e00
 
 #endif
 
diff --git a/include/configs/ls1012a_common.h b/include/configs/ls1012a_common.h
index 148598fab465..b57eb52d1488 100644
--- a/include/configs/ls1012a_common.h
+++ b/include/configs/ls1012a_common.h
@@ -26,7 +26,7 @@
 
 /* GPIO */
 
-#define CONFIG_SYS_NS16550_CLK          (get_serial_clock())
+#define CFG_SYS_NS16550_CLK          (get_serial_clock())
 
 #define CONFIG_HWCONFIG
 #define HWCONFIG_BUFFER_SIZE		128
diff --git a/include/configs/ls1021aiot.h b/include/configs/ls1021aiot.h
index 3f2dfa640c9c..3579f9c8437b 100644
--- a/include/configs/ls1021aiot.h
+++ b/include/configs/ls1021aiot.h
@@ -47,7 +47,7 @@
 /*
  * Serial Port
  */
-#define CONFIG_SYS_NS16550_CLK		get_serial_clock()
+#define CFG_SYS_NS16550_CLK		get_serial_clock()
 
 /*
  * I2C
diff --git a/include/configs/ls1021aqds.h b/include/configs/ls1021aqds.h
index bd2f74c1262a..45665115f662 100644
--- a/include/configs/ls1021aqds.h
+++ b/include/configs/ls1021aqds.h
@@ -227,7 +227,7 @@
  * Serial Port
  */
 #ifndef CONFIG_LPUART
-#define CONFIG_SYS_NS16550_CLK		get_serial_clock()
+#define CFG_SYS_NS16550_CLK		get_serial_clock()
 #endif
 
 /*
diff --git a/include/configs/ls1021atsn.h b/include/configs/ls1021atsn.h
index 8c43f652ab65..1e2db12a83f2 100644
--- a/include/configs/ls1021atsn.h
+++ b/include/configs/ls1021atsn.h
@@ -60,7 +60,7 @@
 #define CONFIG_SYS_SDRAM_BASE		CONFIG_SYS_DDR_SDRAM_BASE
 
 /* Serial Port */
-#define CONFIG_SYS_NS16550_CLK		get_serial_clock()
+#define CFG_SYS_NS16550_CLK		get_serial_clock()
 
 /* I2C */
 
diff --git a/include/configs/ls1021atwr.h b/include/configs/ls1021atwr.h
index 06830f401a31..323feb6e3333 100644
--- a/include/configs/ls1021atwr.h
+++ b/include/configs/ls1021atwr.h
@@ -145,7 +145,7 @@
  * Serial Port
  */
 #ifndef CONFIG_LPUART
-#define CONFIG_SYS_NS16550_CLK		get_serial_clock()
+#define CFG_SYS_NS16550_CLK		get_serial_clock()
 #endif
 
 /*
diff --git a/include/configs/ls1028a_common.h b/include/configs/ls1028a_common.h
index 7dd5649005b7..587f23be587f 100644
--- a/include/configs/ls1028a_common.h
+++ b/include/configs/ls1028a_common.h
@@ -28,7 +28,7 @@
 /* I2C */
 
 /* Serial Port */
-#define CONFIG_SYS_NS16550_CLK          (get_bus_freq(0) / 2)
+#define CFG_SYS_NS16550_CLK          (get_bus_freq(0) / 2)
 
 /* Miscellaneous configurable options */
 
diff --git a/include/configs/ls1043a_common.h b/include/configs/ls1043a_common.h
index 2fc06c1dd2dc..6fc509af232c 100644
--- a/include/configs/ls1043a_common.h
+++ b/include/configs/ls1043a_common.h
@@ -40,7 +40,7 @@
 #define CPU_RELEASE_ADDR               secondary_boot_addr
 
 /* Serial Port */
-#define CONFIG_SYS_NS16550_CLK          (get_serial_clock())
+#define CFG_SYS_NS16550_CLK          (get_serial_clock())
 
 /* SD boot SPL */
 #ifdef CONFIG_SD_BOOT
diff --git a/include/configs/ls1046a_common.h b/include/configs/ls1046a_common.h
index 40b4cb964d11..8a3c87c6abdb 100644
--- a/include/configs/ls1046a_common.h
+++ b/include/configs/ls1046a_common.h
@@ -40,7 +40,7 @@
 #define CPU_RELEASE_ADDR               secondary_boot_addr
 
 /* Serial Port */
-#define CONFIG_SYS_NS16550_CLK          (get_serial_clock())
+#define CFG_SYS_NS16550_CLK          (get_serial_clock())
 
 /* SD boot SPL */
 #ifdef CONFIG_SD_BOOT
diff --git a/include/configs/ls1088a_common.h b/include/configs/ls1088a_common.h
index 5668e07d1354..2117b0811686 100644
--- a/include/configs/ls1088a_common.h
+++ b/include/configs/ls1088a_common.h
@@ -45,7 +45,7 @@
 
 
 /* Serial Port */
-#define CONFIG_SYS_NS16550_CLK          (get_bus_freq(0) / 2)
+#define CFG_SYS_NS16550_CLK          (get_bus_freq(0) / 2)
 
 /*
  * During booting, IFC is mapped at the region of 0x30000000.
diff --git a/include/configs/ls2080a_common.h b/include/configs/ls2080a_common.h
index 895c566fea2f..c79a50795b8c 100644
--- a/include/configs/ls2080a_common.h
+++ b/include/configs/ls2080a_common.h
@@ -37,7 +37,7 @@
 /* I2C */
 
 /* Serial Port */
-#define CONFIG_SYS_NS16550_CLK          (get_serial_clock())
+#define CFG_SYS_NS16550_CLK          (get_serial_clock())
 
 /*
  * During booting, IFC is mapped at the region of 0x30000000.
diff --git a/include/configs/medcom-wide.h b/include/configs/medcom-wide.h
index b90a84da8ad7..a8d8d8b09e02 100644
--- a/include/configs/medcom-wide.h
+++ b/include/configs/medcom-wide.h
@@ -16,7 +16,7 @@
 
 /* Board-specific serial config */
 #define CONFIG_TEGRA_ENABLE_UARTD	/* UARTD: debug UART */
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
 
 /* NAND support */
 
diff --git a/include/configs/mt7621.h b/include/configs/mt7621.h
index 1f733d112dd7..e09e9c82eb8d 100644
--- a/include/configs/mt7621.h
+++ b/include/configs/mt7621.h
@@ -22,8 +22,8 @@
 
 /* Serial SPL */
 #if defined(CONFIG_SPL_BUILD) && defined(CONFIG_SPL_SERIAL)
-#define CONFIG_SYS_NS16550_CLK		50000000
-#define CONFIG_SYS_NS16550_COM1		0xbe000c00
+#define CFG_SYS_NS16550_CLK		50000000
+#define CFG_SYS_NS16550_COM1		0xbe000c00
 #endif
 
 /* Serial common */
diff --git a/include/configs/mt7628.h b/include/configs/mt7628.h
index da16e3b21a4b..bb12ebfe4fd0 100644
--- a/include/configs/mt7628.h
+++ b/include/configs/mt7628.h
@@ -14,8 +14,8 @@
 
 /* Serial SPL */
 #if defined(CONFIG_SPL_BUILD) && defined(CONFIG_SPL_SERIAL)
-#define CONFIG_SYS_NS16550_CLK		40000000
-#define CONFIG_SYS_NS16550_COM1		0xb0000c00
+#define CFG_SYS_NS16550_CLK		40000000
+#define CFG_SYS_NS16550_COM1		0xb0000c00
 #endif
 
 /* Serial common */
diff --git a/include/configs/mt8183.h b/include/configs/mt8183.h
index eaffe0bf4c95..3da7619d78d7 100644
--- a/include/configs/mt8183.h
+++ b/include/configs/mt8183.h
@@ -12,8 +12,8 @@
 #include <linux/sizes.h>
 
 
-#define CONFIG_SYS_NS16550_COM1		0x11005200
-#define CONFIG_SYS_NS16550_CLK		26000000
+#define CFG_SYS_NS16550_COM1		0x11005200
+#define CFG_SYS_NS16550_CLK		26000000
 
 /* Environment settings */
 #include <config_distro_bootcmd.h>
diff --git a/include/configs/mt8516.h b/include/configs/mt8516.h
index 347598868bb5..0f7981a56611 100644
--- a/include/configs/mt8516.h
+++ b/include/configs/mt8516.h
@@ -12,8 +12,8 @@
 #include <linux/sizes.h>
 
 
-#define CONFIG_SYS_NS16550_COM1		0x11005000
-#define CONFIG_SYS_NS16550_CLK		26000000
+#define CFG_SYS_NS16550_COM1		0x11005000
+#define CFG_SYS_NS16550_CLK		26000000
 
 /* Environment settings */
 #include <config_distro_bootcmd.h>
diff --git a/include/configs/mv-common.h b/include/configs/mv-common.h
index 4f1067c23bbc..e870fc810cb1 100644
--- a/include/configs/mv-common.h
+++ b/include/configs/mv-common.h
@@ -32,9 +32,9 @@
 /*
  * NS16550 Configuration
  */
-#define CONFIG_SYS_NS16550_CLK		CONFIG_SYS_TCLK
+#define CFG_SYS_NS16550_CLK		CONFIG_SYS_TCLK
 #if !defined(CONFIG_DM_SERIAL)
-#define CONFIG_SYS_NS16550_COM1		MV_UART_CONSOLE_BASE
+#define CFG_SYS_NS16550_COM1		MV_UART_CONSOLE_BASE
 #endif
 
 #if defined(CONFIG_ARMADA_38X) && !defined(CONFIG_SYS_BAUDRATE_TABLE)
diff --git a/include/configs/nokia_rx51.h b/include/configs/nokia_rx51.h
index 6f16e336d146..cc4784232f9b 100644
--- a/include/configs/nokia_rx51.h
+++ b/include/configs/nokia_rx51.h
@@ -40,12 +40,12 @@
  */
 #define V_NS16550_CLK		48000000		/* 48MHz (APLL96/2) */
 
-#define CONFIG_SYS_NS16550_CLK		V_NS16550_CLK
+#define CFG_SYS_NS16550_CLK		V_NS16550_CLK
 
 /*
  * select serial console configuration
  */
-#define CONFIG_SYS_NS16550_COM3		OMAP34XX_UART3
+#define CFG_SYS_NS16550_COM3		OMAP34XX_UART3
 
 #define CONFIG_SYS_BAUDRATE_TABLE { 4800, 9600, 19200, 38400, 57600, 115200 }
 
diff --git a/include/configs/nyan-big.h b/include/configs/nyan-big.h
index c59e10324395..baa452156ecd 100644
--- a/include/configs/nyan-big.h
+++ b/include/configs/nyan-big.h
@@ -16,7 +16,7 @@
 
 /* Board-specific serial config */
 #define CONFIG_TEGRA_ENABLE_UARTA
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
 
 /* SPI */
 #define CONFIG_SPI_FLASH_SIZE          (4 << 20)
diff --git a/include/configs/omap5_uevm.h b/include/configs/omap5_uevm.h
index cce5556fe266..883cc0b99c9e 100644
--- a/include/configs/omap5_uevm.h
+++ b/include/configs/omap5_uevm.h
@@ -28,7 +28,7 @@
 
 #include <configs/ti_omap5_common.h>
 
-#define CONFIG_SYS_NS16550_COM3		UART3_BASE
+#define CFG_SYS_NS16550_COM3		UART3_BASE
 
 /* MMC ENV related defines */
 
diff --git a/include/configs/omapl138_lcdk.h b/include/configs/omapl138_lcdk.h
index 81ca68de9bcc..2b47d4ca3768 100644
--- a/include/configs/omapl138_lcdk.h
+++ b/include/configs/omapl138_lcdk.h
@@ -91,7 +91,7 @@
 /*
  * Serial Driver info
  */
-#define CONFIG_SYS_NS16550_CLK	clk_get(DAVINCI_UART2_CLKID)
+#define CFG_SYS_NS16550_CLK	clk_get(DAVINCI_UART2_CLKID)
 
 #define CONFIG_SYS_SPI_BASE		DAVINCI_SPI1_BASE
 #define CONFIG_SYS_SPI_CLK		clk_get(DAVINCI_SPI1_CLKID)
diff --git a/include/configs/p1_p2_rdb_pc.h b/include/configs/p1_p2_rdb_pc.h
index 065820689caf..9fc22f0a6cbc 100644
--- a/include/configs/p1_p2_rdb_pc.h
+++ b/include/configs/p1_p2_rdb_pc.h
@@ -319,13 +319,13 @@
  * shorted - index 1
  */
 #undef CONFIG_SERIAL_SOFTWARE_FIFO
-#define CONFIG_SYS_NS16550_CLK		get_bus_freq(0)
+#define CFG_SYS_NS16550_CLK		get_bus_freq(0)
 
 #define CONFIG_SYS_BAUDRATE_TABLE	\
 	{300, 600, 1200, 2400, 4800, 9600, 19200, 38400, 57600, 115200}
 
-#define CONFIG_SYS_NS16550_COM1	(CONFIG_SYS_CCSRBAR+0x4500)
-#define CONFIG_SYS_NS16550_COM2	(CONFIG_SYS_CCSRBAR+0x4600)
+#define CFG_SYS_NS16550_COM1	(CONFIG_SYS_CCSRBAR+0x4500)
+#define CFG_SYS_NS16550_COM2	(CONFIG_SYS_CCSRBAR+0x4600)
 
 /* I2C */
 #if !CONFIG_IS_ENABLED(DM_I2C)
diff --git a/include/configs/paz00.h b/include/configs/paz00.h
index c12f4d0937d5..a945f4e9b289 100644
--- a/include/configs/paz00.h
+++ b/include/configs/paz00.h
@@ -17,7 +17,7 @@
 
 /* Board-specific serial config */
 #define CONFIG_TEGRA_ENABLE_UARTA
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
 
 /* Environment in eMMC, at the end of 2nd "boot sector" */
 
diff --git a/include/configs/pdu001.h b/include/configs/pdu001.h
index ed3201aa3c42..71807837673f 100644
--- a/include/configs/pdu001.h
+++ b/include/configs/pdu001.h
@@ -50,11 +50,11 @@
 	"\0"
 
 /* NS16550 Configuration */
-#define CONFIG_SYS_NS16550_COM1	UART0_BASE
-#define CONFIG_SYS_NS16550_COM2	UART1_BASE
-#define CONFIG_SYS_NS16550_COM3	UART2_BASE
-#define CONFIG_SYS_NS16550_COM4	UART3_BASE
-#define CONFIG_SYS_NS16550_COM5	UART4_BASE
-#define CONFIG_SYS_NS16550_COM6	UART5_BASE
+#define CFG_SYS_NS16550_COM1	UART0_BASE
+#define CFG_SYS_NS16550_COM2	UART1_BASE
+#define CFG_SYS_NS16550_COM3	UART2_BASE
+#define CFG_SYS_NS16550_COM4	UART3_BASE
+#define CFG_SYS_NS16550_COM5	UART4_BASE
+#define CFG_SYS_NS16550_COM6	UART5_BASE
 
 #endif	/* ! __CONFIG_PDU001_H */
diff --git a/include/configs/plutux.h b/include/configs/plutux.h
index 09f0ed9b9a1b..99db59c489e0 100644
--- a/include/configs/plutux.h
+++ b/include/configs/plutux.h
@@ -16,7 +16,7 @@
 
 /* Board-specific serial config */
 #define CONFIG_TEGRA_ENABLE_UARTD	/* UARTD: debug UART */
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
 
 /* NAND support */
 
diff --git a/include/configs/seaboard.h b/include/configs/seaboard.h
index c7f03a1e7543..4887747968f2 100644
--- a/include/configs/seaboard.h
+++ b/include/configs/seaboard.h
@@ -22,7 +22,7 @@
 
 /* Board-specific serial config */
 #define CONFIG_TEGRA_ENABLE_UARTD
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
 
 /* Environment in eMMC, at the end of 2nd "boot sector" */
 
diff --git a/include/configs/siemens-am33x-common.h b/include/configs/siemens-am33x-common.h
index 5765f2ccb5e7..c9dd7509cb2a 100644
--- a/include/configs/siemens-am33x-common.h
+++ b/include/configs/siemens-am33x-common.h
@@ -38,9 +38,9 @@
 #define CONFIG_SYS_TIMERBASE		0x48040000	/* Use Timer2 */
 
 /* NS16550 Configuration */
-#define CONFIG_SYS_NS16550_CLK		(48000000)
-#define CONFIG_SYS_NS16550_COM1		0x44e09000
-#define CONFIG_SYS_NS16550_COM4		0x481a6000
+#define CFG_SYS_NS16550_CLK		(48000000)
+#define CFG_SYS_NS16550_COM1		0x44e09000
+#define CFG_SYS_NS16550_COM4		0x481a6000
 
 
 /* I2C Configuration */
diff --git a/include/configs/sniper.h b/include/configs/sniper.h
index c29bc448eed6..6054fa42c1a2 100644
--- a/include/configs/sniper.h
+++ b/include/configs/sniper.h
@@ -52,8 +52,8 @@
  * Serial
  */
 
-#define CONFIG_SYS_NS16550_CLK		V_NS16550_CLK
-#define CONFIG_SYS_NS16550_COM3		OMAP34XX_UART3
+#define CFG_SYS_NS16550_CLK		V_NS16550_CLK
+#define CFG_SYS_NS16550_COM3		OMAP34XX_UART3
 
 #define CONFIG_SYS_BAUDRATE_TABLE	{ 4800, 9600, 19200, 38400, 57600, \
 					  115200 }
diff --git a/include/configs/socfpga_soc64_common.h b/include/configs/socfpga_soc64_common.h
index 029f898b64ff..2b2d78b8c8e0 100644
--- a/include/configs/socfpga_soc64_common.h
+++ b/include/configs/socfpga_soc64_common.h
@@ -75,7 +75,7 @@
 /*
  * Serial / UART configurations
  */
-#define CONFIG_SYS_NS16550_CLK		100000000
+#define CFG_SYS_NS16550_CLK		100000000
 
 /*
  * SDMMC configurations
diff --git a/include/configs/sunxi-common.h b/include/configs/sunxi-common.h
index 1ed0a262bc61..cd2a74fb52d7 100644
--- a/include/configs/sunxi-common.h
+++ b/include/configs/sunxi-common.h
@@ -19,16 +19,16 @@
 /* ns16550 reg in the low bits of cpu reg */
 #ifdef CONFIG_MACH_SUNIV
 /* suniv doesn't have apb2 and uart is connected to apb1 */
-#define CONFIG_SYS_NS16550_CLK		100000000
+#define CFG_SYS_NS16550_CLK		100000000
 #else
-#define CONFIG_SYS_NS16550_CLK		24000000
+#define CFG_SYS_NS16550_CLK		24000000
 #endif
 #ifndef CONFIG_DM_SERIAL
-# define CONFIG_SYS_NS16550_COM1		SUNXI_UART0_BASE
-# define CONFIG_SYS_NS16550_COM2		SUNXI_UART1_BASE
-# define CONFIG_SYS_NS16550_COM3		SUNXI_UART2_BASE
-# define CONFIG_SYS_NS16550_COM4		SUNXI_UART3_BASE
-# define CONFIG_SYS_NS16550_COM5		SUNXI_R_UART_BASE
+# define CFG_SYS_NS16550_COM1		SUNXI_UART0_BASE
+# define CFG_SYS_NS16550_COM2		SUNXI_UART1_BASE
+# define CFG_SYS_NS16550_COM3		SUNXI_UART2_BASE
+# define CFG_SYS_NS16550_COM4		SUNXI_UART3_BASE
+# define CFG_SYS_NS16550_COM5		SUNXI_R_UART_BASE
 #endif
 
 /* CPU */
diff --git a/include/configs/tb100.h b/include/configs/tb100.h
index 38a43b726f03..92ee920346bb 100644
--- a/include/configs/tb100.h
+++ b/include/configs/tb100.h
@@ -19,7 +19,7 @@
 /*
  * UART configuration
  */
-#define CONFIG_SYS_NS16550_CLK		166666666
+#define CFG_SYS_NS16550_CLK		166666666
 
 /*
  * Even though the board houses Realtek RTL8211E PHY
diff --git a/include/configs/tec-ng.h b/include/configs/tec-ng.h
index f8e741ab6fc1..098796637010 100644
--- a/include/configs/tec-ng.h
+++ b/include/configs/tec-ng.h
@@ -14,7 +14,7 @@
 
 /* Board-specific serial config */
 #define CONFIG_TEGRA_ENABLE_UARTD
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
 
 /* Environment in eMMC, at the end of 2nd "boot sector" */
 
diff --git a/include/configs/tec.h b/include/configs/tec.h
index 2377b47e0541..ddf753da4a9f 100644
--- a/include/configs/tec.h
+++ b/include/configs/tec.h
@@ -16,7 +16,7 @@
 
 /* Board-specific serial config */
 #define CONFIG_TEGRA_ENABLE_UARTD	/* UARTD: debug UART */
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
 
 /* NAND support */
 
diff --git a/include/configs/tegra-common.h b/include/configs/tegra-common.h
index 2915db7f8bf7..92df457e8189 100644
--- a/include/configs/tegra-common.h
+++ b/include/configs/tegra-common.h
@@ -26,7 +26,7 @@
 /*
  * NS16550 Configuration
  */
-#define CONFIG_SYS_NS16550_CLK		V_NS16550_CLK
+#define CFG_SYS_NS16550_CLK		V_NS16550_CLK
 
 #ifdef CONFIG_ARM64
 #define FDTFILE "nvidia/" CONFIG_DEFAULT_DEVICE_TREE ".dtb"
diff --git a/include/configs/ti814x_evm.h b/include/configs/ti814x_evm.h
index 60632c58c67d..9614fe686f6b 100644
--- a/include/configs/ti814x_evm.h
+++ b/include/configs/ti814x_evm.h
@@ -77,8 +77,8 @@
 #define CONFIG_SYS_TIMERBASE		0x4802E000
 
 /* NS16550 Configuration */
-#define CONFIG_SYS_NS16550_CLK		(48000000)
-#define CONFIG_SYS_NS16550_COM1		0x48020000	/* Base EVM has UART0 */
+#define CFG_SYS_NS16550_CLK		(48000000)
+#define CFG_SYS_NS16550_COM1		0x48020000	/* Base EVM has UART0 */
 
 /* CPU */
 
diff --git a/include/configs/ti816x_evm.h b/include/configs/ti816x_evm.h
index f2dbe3544a5d..1bd2a1874b86 100644
--- a/include/configs/ti816x_evm.h
+++ b/include/configs/ti816x_evm.h
@@ -30,8 +30,8 @@
 /*
  * NS16550 Configuration
  */
-#define CONFIG_SYS_NS16550_CLK      (48000000)
-#define CONFIG_SYS_NS16550_COM1     0x48024000  /* Base EVM has UART2 */
+#define CFG_SYS_NS16550_CLK      (48000000)
+#define CFG_SYS_NS16550_COM1     0x48024000  /* Base EVM has UART2 */
 
 /* allow overwriting serial config and ethaddr */
 
diff --git a/include/configs/ti_am335x_common.h b/include/configs/ti_am335x_common.h
index fb017771688e..00eb329faa83 100644
--- a/include/configs/ti_am335x_common.h
+++ b/include/configs/ti_am335x_common.h
@@ -17,7 +17,7 @@
 #include <asm/arch/omap.h>
 
 /* NS16550 Configuration */
-#define CONFIG_SYS_NS16550_CLK		48000000
+#define CFG_SYS_NS16550_CLK		48000000
 
 /*
  * SPL related defines.  The Public RAM memory map the ROM defines the
diff --git a/include/configs/ti_armv7_keystone2.h b/include/configs/ti_armv7_keystone2.h
index aaeea77281b6..119b4c0410c7 100644
--- a/include/configs/ti_armv7_keystone2.h
+++ b/include/configs/ti_armv7_keystone2.h
@@ -34,13 +34,13 @@
 #define KEYSTONE_SRAM_SCRATCH_SPACE_END		(TI_SRAM_SCRATCH_BOARD_EEPROM_END)
 
 /* UART Configuration */
-#define CONFIG_SYS_NS16550_COM1		KS2_UART0_BASE
-#define CONFIG_SYS_NS16550_COM2		KS2_UART1_BASE
+#define CFG_SYS_NS16550_COM1		KS2_UART0_BASE
+#define CFG_SYS_NS16550_COM2		KS2_UART1_BASE
 
 #ifndef CONFIG_SOC_K2G
-#define CONFIG_SYS_NS16550_CLK		ks_clk_get_rate(KS2_CLK1_6)
+#define CFG_SYS_NS16550_CLK		ks_clk_get_rate(KS2_CLK1_6)
 #else
-#define CONFIG_SYS_NS16550_CLK		ks_clk_get_rate(uart_pll_clk) / 2
+#define CFG_SYS_NS16550_CLK		ks_clk_get_rate(uart_pll_clk) / 2
 #endif
 
 /* SPI Configuration */
diff --git a/include/configs/ti_omap3_common.h b/include/configs/ti_omap3_common.h
index 80d2a011f0fe..d282c3956e0c 100644
--- a/include/configs/ti_omap3_common.h
+++ b/include/configs/ti_omap3_common.h
@@ -26,15 +26,15 @@
 
 /* NS16550 Configuration */
 #define V_NS16550_CLK			48000000	/* 48MHz (APLL96/2) */
-#define CONFIG_SYS_NS16550_CLK		V_NS16550_CLK
+#define CFG_SYS_NS16550_CLK		V_NS16550_CLK
 #define CONFIG_SYS_BAUDRATE_TABLE	{4800, 9600, 19200, 38400, 57600, \
 					115200}
 
 /* Select serial console configuration */
 #ifdef CONFIG_SPL_BUILD
-#define CONFIG_SYS_NS16550_COM1		OMAP34XX_UART1
-#define CONFIG_SYS_NS16550_COM2		OMAP34XX_UART2
-#define CONFIG_SYS_NS16550_COM3		OMAP34XX_UART3
+#define CFG_SYS_NS16550_COM1		OMAP34XX_UART1
+#define CFG_SYS_NS16550_COM2		OMAP34XX_UART2
+#define CFG_SYS_NS16550_COM3		OMAP34XX_UART3
 #endif
 
 /* Physical Memory Map */
diff --git a/include/configs/ti_omap4_common.h b/include/configs/ti_omap4_common.h
index eb930341c3a8..ce50e35d8d4b 100644
--- a/include/configs/ti_omap4_common.h
+++ b/include/configs/ti_omap4_common.h
@@ -27,9 +27,9 @@
 /*
  * Hardware drivers
  */
-#define CONFIG_SYS_NS16550_CLK		48000000
+#define CFG_SYS_NS16550_CLK		48000000
 #if defined(CONFIG_SPL_BUILD) || !defined(CONFIG_DM_SERIAL)
-#define CONFIG_SYS_NS16550_COM3		UART3_BASE
+#define CFG_SYS_NS16550_COM3		UART3_BASE
 #endif
 
 /* TWL6030 */
diff --git a/include/configs/ti_omap5_common.h b/include/configs/ti_omap5_common.h
index a1efb57f1b09..c49c177390b3 100644
--- a/include/configs/ti_omap5_common.h
+++ b/include/configs/ti_omap5_common.h
@@ -29,7 +29,7 @@
 /*
  * Hardware drivers
  */
-#define CONFIG_SYS_NS16550_CLK		48000000
+#define CFG_SYS_NS16550_CLK		48000000
 
 /*
  * Environment setup
diff --git a/include/configs/tplink_wdr4300.h b/include/configs/tplink_wdr4300.h
index b14726ad234f..22d783c325b2 100644
--- a/include/configs/tplink_wdr4300.h
+++ b/include/configs/tplink_wdr4300.h
@@ -14,7 +14,7 @@
 /*
  * Serial Port
  */
-#define CONFIG_SYS_NS16550_CLK		40000000
+#define CFG_SYS_NS16550_CLK		40000000
 
 /*
  * Command
diff --git a/include/configs/trimslice.h b/include/configs/trimslice.h
index b562d44a13ba..e4cbc7da843e 100644
--- a/include/configs/trimslice.h
+++ b/include/configs/trimslice.h
@@ -16,7 +16,7 @@
 /* Board-specific serial config */
 #define CONFIG_TEGRA_ENABLE_UARTA
 #define CONFIG_TEGRA_UARTA_GPU
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
 
 /* SPI */
 
diff --git a/include/configs/vcoreiii.h b/include/configs/vcoreiii.h
index 02ddc6fb6e0b..338d8af8fb36 100644
--- a/include/configs/vcoreiii.h
+++ b/include/configs/vcoreiii.h
@@ -12,7 +12,7 @@
 
 #define CONFIG_SYS_INIT_SP_OFFSET       0x400000
 
-#define CONFIG_SYS_NS16550_CLK		CONFIG_SYS_MIPS_TIMER_FREQ
+#define CFG_SYS_NS16550_CLK		CONFIG_SYS_MIPS_TIMER_FREQ
 
 #define CONFIG_SYS_SDRAM_BASE		0x80000000
 #if defined(CONFIG_DDRTYPE_H5TQ1G63BFA) || defined(CONFIG_DDRTYPE_MT47H128M8HQ)
diff --git a/include/configs/venice2.h b/include/configs/venice2.h
index 03aa7adcc0d3..b2dc04a975ad 100644
--- a/include/configs/venice2.h
+++ b/include/configs/venice2.h
@@ -16,7 +16,7 @@
 
 /* Board-specific serial config */
 #define CONFIG_TEGRA_ENABLE_UARTA
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
 
 /* Environment in eMMC, at the end of 2nd "boot sector" */
 
diff --git a/include/configs/ventana.h b/include/configs/ventana.h
index 0bd5a1e85228..f7a507768ec1 100644
--- a/include/configs/ventana.h
+++ b/include/configs/ventana.h
@@ -15,7 +15,7 @@
 
 /* Board-specific serial config */
 #define CONFIG_TEGRA_ENABLE_UARTD
-#define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
+#define CFG_SYS_NS16550_COM1		NV_PA_APB_UARTD_BASE
 
 /* Environment in eMMC, at the end of 2nd "boot sector" */
 
diff --git a/include/configs/vocore2.h b/include/configs/vocore2.h
index 84e5ba39f148..2107bec6587a 100644
--- a/include/configs/vocore2.h
+++ b/include/configs/vocore2.h
@@ -19,8 +19,8 @@
 #define CONFIG_SYS_UBOOT_BASE		0
 
 /* Serial SPL */
-#define CONFIG_SYS_NS16550_CLK		40000000
-#define CONFIG_SYS_NS16550_COM3		0xb0000e00
+#define CFG_SYS_NS16550_CLK		40000000
+#define CFG_SYS_NS16550_COM3		0xb0000e00
 
 /* RAM */
 
diff --git a/include/configs/x530.h b/include/configs/x530.h
index 318e3680a6e1..a0162cab2190 100644
--- a/include/configs/x530.h
+++ b/include/configs/x530.h
@@ -13,9 +13,9 @@
 /*
  * NS16550 Configuration
  */
-#define CONFIG_SYS_NS16550_CLK		CONFIG_SYS_TCLK
+#define CFG_SYS_NS16550_CLK		CONFIG_SYS_TCLK
 #if !defined(CONFIG_DM_SERIAL)
-#define CONFIG_SYS_NS16550_COM1		MV_UART_CONSOLE_BASE
+#define CFG_SYS_NS16550_COM1		MV_UART_CONSOLE_BASE
 #endif
 
 /*
diff --git a/include/configs/xtfpga.h b/include/configs/xtfpga.h
index 7090fcef6804..b93451cbe07a 100644
--- a/include/configs/xtfpga.h
+++ b/include/configs/xtfpga.h
@@ -127,10 +127,10 @@
 /* Serial Driver Info */
 /*====================*/
 
-#define CONFIG_SYS_NS16550_COM1		IOADDR(0x0D050020) /* Base address */
+#define CFG_SYS_NS16550_COM1		IOADDR(0x0D050020) /* Base address */
 
 /* Input clk to NS16550 (in Hz; the SYS_CLK_FREQ is in kHz) */
-#define CONFIG_SYS_NS16550_CLK		get_board_sys_clk()
+#define CFG_SYS_NS16550_CLK		get_board_sys_clk()
 
 /*======================*/
 /* Ethernet Driver Info */
diff --git a/arch/powerpc/cpu/mpc85xx/fdt.c b/arch/powerpc/cpu/mpc85xx/fdt.c
index 1161938d304f..6dd61caf1c47 100644
--- a/arch/powerpc/cpu/mpc85xx/fdt.c
+++ b/arch/powerpc/cpu/mpc85xx/fdt.c
@@ -649,7 +649,7 @@ void ft_cpu_setup(void *blob, struct bd_info *bd)
 
 #ifdef CONFIG_SYS_NS16550
 	do_fixup_by_compat_u32(blob, "ns16550",
-		"clock-frequency", CONFIG_SYS_NS16550_CLK, 1);
+		"clock-frequency", CFG_SYS_NS16550_CLK, 1);
 #endif
 
 #ifdef CONFIG_FSL_CORENET
@@ -751,7 +751,7 @@ static void msg(const char *name, uint64_t uaddr, uint64_t daddr)
  * This function compares several CONFIG_xxx macros that contain physical
  * addresses with the corresponding nodes in the device tree, to see if
  * the physical addresses are all correct.  For example, if
  * CONFIG_SYS_NS16550_COM1 is defined, then it contains the virtual address
  * of the first UART.  We convert this to a physical address and compare
  * that with the physical address of the first ns16550-compatible node
  * in the device tree.  If they don't match, then we display a warning.
@@ -796,15 +796,15 @@ int ft_verify_fdt(void *fdt)
 	 */
 	aliases = fdt_path_offset(fdt, "/aliases");
 	if (aliases > 0) {
-#ifdef CONFIG_SYS_NS16550_COM1
+#ifdef CFG_SYS_NS16550_COM1
 		if (!fdt_verify_alias_address(fdt, aliases, "serial0",
-			CCSR_VIRT_TO_PHYS(CONFIG_SYS_NS16550_COM1)))
+			CCSR_VIRT_TO_PHYS(CFG_SYS_NS16550_COM1)))
 			return 0;
 #endif
 
-#ifdef CONFIG_SYS_NS16550_COM2
+#ifdef CFG_SYS_NS16550_COM2
 		if (!fdt_verify_alias_address(fdt, aliases, "serial1",
-			CCSR_VIRT_TO_PHYS(CONFIG_SYS_NS16550_COM2)))
+			CCSR_VIRT_TO_PHYS(CFG_SYS_NS16550_COM2)))
 			return 0;
 #endif
 	}
@@ -751,7 +751,7 @@ static void msg(const char *name, uint64_t uaddr, uint64_t daddr)
  * addresses with the corresponding nodes in the device tree, to see if
  * the physical addresses are all correct.  For example, if
- * CONFIG_SYS_NS16550_COM1 is defined, then it contains the virtual address
+ * CFG_SYS_NS16550_COM1 is defined, then it contains the virtual address
  * of the first UART.  We convert this to a physical address and compare
  * that with the physical address of the first ns16550-compatible node
-- 
2.25.1



More information about the U-Boot mailing list